@@ -58,21 +58,21 @@ void ServiceWin32AccountHandler::embedDialogWidgets(void* pEmbeddingParent)
 	
 	/* Non-Tabbable Labels */
 
-	m_hEmailLabel = CreateWindowEx(WS_EX_NOPARENTNOTIFY, "STATIC", "E-mail address:", SS_LEFT | WS_CHILD | WS_VISIBLE | WS_GROUP,
+	m_hEmailLabel = CreateWindowEx(WS_EX_NOPARENTNOTIFY, "STATIC", "E-mail address:", SS_LEFT | WS_CHILD | WS_VISIBLE,
 			15, 20, 51, 15, hBox,  (HMENU) ABI_RID_DIALOG_COLLABSERVICE_EMAILLABEL,  m_hInstance, 0);
 	UT_return_if_fail(m_hEmailLabel);
 
-	m_hPasswordLabel = CreateWindowEx(WS_EX_NOPARENTNOTIFY, "STATIC", "Password:", SS_LEFT | WS_CHILD | WS_VISIBLE | WS_GROUP,
+	m_hPasswordLabel = CreateWindowEx(WS_EX_NOPARENTNOTIFY, "STATIC", "Password:", SS_LEFT | WS_CHILD | WS_VISIBLE,
 			15, 40, 51, 15, hBox,  (HMENU) ABI_RID_DIALOG_COLLABSERVICE_PASSWORDLABEL,  m_hInstance, 0);
 	UT_return_if_fail(m_hPasswordLabel);
 	
 	/* Tabbable */
-	m_hEmailEntry = CreateWindowEx(WS_EX_NOPARENTNOTIFY | WS_EX_CLIENTEDGE, "EDIT", "", ES_AUTOHSCROLL | ES_LEFT | WS_CHILD | WS_BORDER | WS_VISIBLE | WS_TABSTOP | WS_GROUP,
+	m_hEmailEntry = CreateWindowEx(WS_EX_NOPARENTNOTIFY | WS_EX_CLIENTEDGE, "EDIT", "", ES_AUTOHSCROLL | ES_LEFT | WS_CHILD | WS_BORDER | WS_VISIBLE | WS_TABSTOP,
 			80, 20, 121, 20, hBox,  (HMENU) ABI_RID_DIALOG_COLLABSERVICE_EMAILENTRY,  m_hInstance, 0);
 	UT_return_if_fail(m_hEmailEntry);
 	SendMessage(m_hEmailEntry, EM_SETLIMITTEXT, 255*sizeof(TCHAR), 0);
 
-	m_hPasswordEntry = CreateWindowEx(WS_EX_NOPARENTNOTIFY | WS_EX_CLIENTEDGE, "EDIT", "", ES_AUTOHSCROLL | ES_LEFT | WS_CHILD | WS_BORDER | WS_VISIBLE | WS_TABSTOP | WS_GROUP,
+	m_hPasswordEntry = CreateWindowEx(WS_EX_NOPARENTNOTIFY | WS_EX_CLIENTEDGE, "EDIT", "", ES_AUTOHSCROLL | ES_LEFT | WS_CHILD | WS_BORDER | WS_VISIBLE | WS_TABSTOP,
 			80, 40, 121, 20, hBox,  (HMENU) ABI_RID_DIALOG_COLLABSERVICE_PASSWORDENTRY,  m_hInstance, 0);
 	UT_return_if_fail(m_hPasswordEntry);
 	SendMessage(m_hPasswordEntry, EM_SETPASSWORDCHAR, '*', 0);
@@ -147,4 +147,9 @@ BOOL ServiceWin32AccountHandler::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lPa
 	}
 
 	return false;
-}
\ No newline at end of file
+}
+
+bool ServiceWin32AccountHandler::shouldProcessFocus()
+{
+	return GetFocus() != m_hUrlButton;
+}
