@@ -28,6 +28,8 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include "SugarBuddy.h"
 
+#define SUGAR_STATIC_STORAGE_TYPE "com.abisource.abiword.abicollab.backend.sugar"
+
 extern AccountHandlerConstructor SugarAccountHandlerConstructor;
 
 class Session;
@@ -58,8 +60,6 @@ public:
 	virtual ConnectResult					connect();
 	virtual bool							disconnect();
 	virtual bool							isOnline();
-	bool									isLocallyControlled()
-		{ return m_bLocallyControlled; }
 	
 	// user management
 	virtual BuddyPtr						constructBuddy(const PropertyMap& props);
@@ -74,7 +74,7 @@ public:
 
 	// session management
 	virtual bool							allowsSessionTakeover()
-		{ return false; }
+		{ return true; }
 	virtual bool							canManuallyStartSession()
 		{ return false; }
 
@@ -93,6 +93,7 @@ public:
 	SugarBuddyPtr							getBuddy(const UT_UTF8String& dbusAddress);
 	bool									offerTube(FV_View* pView, const UT_UTF8String& tubeDBusAddress);
 	bool									joinTube(FV_View* pView, const UT_UTF8String& tubeDBusAddress);
+	bool									disconnectTube(FV_View* pView);
 	bool									joinBuddy(FV_View* pView, const UT_UTF8String& buddyDBusAddress);
 	bool									disjoinBuddy(FV_View* pView, const UT_UTF8String& buddyDBusAddress);
 
@@ -100,14 +101,16 @@ public:
 		{ return m_ignoredBuddies.find(buddyName) != m_ignoredBuddies.end(); }
 	
 protected:
-	// control management
+	bool									_send(const Packet* pPacket, const char* dbusAddress);
 	void									_registerEditMethods();
+	virtual	void							_handlePacket(Packet* packet, BuddyPtr buddy);
 
 private:
 	static SugarAccountHandler* 			m_pHandler;
 	DBusConnection*							m_pTube;
-	bool									m_bLocallyControlled;
+	bool									m_bIsInSession;
 	std::set<UT_UTF8String>					m_ignoredBuddies;
+	UT_UTF8String							m_sSessionId;
 };
 
 #endif /* __SUGARACCOUNTHANDLER__ */
