@@ -79,11 +79,9 @@ ChangeAdjust::~ChangeAdjust()
 AbiCollab::AbiCollab(PD_Document* pDoc, 
 						const UT_UTF8String& sSessionId, 
 						AccountHandler* pAclAccount,
-						bool bLocallyOwned,
-						XAP_Frame* pFrame)
+						bool bLocallyOwned)
 	: EV_MouseListener(),
 	m_pDoc(pDoc),
-	m_pFrame(pFrame),
 	m_Import(this, pDoc),
 	m_Export(this, pDoc),
 	m_pAclAccount(pAclAccount),
@@ -95,7 +93,6 @@ AbiCollab::AbiCollab(PD_Document* pDoc,
 	m_pActivePacket(NULL),
 	m_bIsReverting(false),
 	m_pRecorder(NULL),
-	m_iMouseLID(-1),
 	m_bDoingMouseDrag(false),
 	m_eTakeoveState(STS_NONE),
 	m_bProposedController(false),
@@ -105,7 +102,7 @@ AbiCollab::AbiCollab(PD_Document* pDoc,
 	// TODO: this can be made a lil' more efficient, as setDocument
 	// will create import and export listeners, which is kinda useless
 	// when there is no single collaborator yet
-	_setDocument(pDoc, pFrame);
+	_setDocument(pDoc);
 	
 	m_Import.masterInit();
 	m_Export.masterInit();
@@ -122,11 +119,9 @@ AbiCollab::AbiCollab(const UT_UTF8String& sSessionId,
 						UT_sint32 iRev, 
 						BuddyPtr pController,
 						AccountHandler* pAclAccount,
-						bool bLocallyOwned,
-						XAP_Frame* pFrame)
+						bool bLocallyOwned)
 	: EV_MouseListener(),
 	m_pDoc(pDoc),
-	m_pFrame(pFrame),
 	m_Import(this, pDoc),
 	m_Export(this, pDoc),
 	m_pAclAccount(pAclAccount),
@@ -138,7 +133,6 @@ AbiCollab::AbiCollab(const UT_UTF8String& sSessionId,
 	m_pActivePacket(NULL),
 	m_bIsReverting(false),
 	m_pRecorder(NULL),
-	m_iMouseLID(-1),
 	m_bDoingMouseDrag(false),
 	m_eTakeoveState(STS_NONE),
 	m_bProposedController(false),
@@ -148,7 +142,7 @@ AbiCollab::AbiCollab(const UT_UTF8String& sSessionId,
 	// TODO: this can be made a lil' more efficient, as setDocument
 	// will create import and export listeners, which is kinda useless
 	// when there is no single collaborator yet
-	_setDocument(pDoc, pFrame);
+	_setDocument(pDoc);
 
 	m_Import.slaveInit(pController, iRev);
 	m_Export.slaveInit(docUUID, iRev);
@@ -169,23 +163,18 @@ AbiCollab::~AbiCollab(void)
 {
 	UT_DEBUGMSG(("AbiCollab::~AbiCollab()\n"));
 	
-	if (m_iMouseLID != -1)
+	for (std::map<EV_Mouse*, UT_sint32>::iterator cit = m_mMouseListenerIds.begin(); cit != m_mMouseListenerIds.end(); cit++)
 	{
-		XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
-		if (pFrame)
-		{
-			// FIXME: we should do this for all frames that display this document!
-			EV_Mouse* pMouse = pFrame->getMouse();
-			if (pMouse)
-				pMouse->unregisterListener(m_iMouseLID);
-		}
+		EV_Mouse* pMouse = (*cit).first;
+		UT_sint32 iListenerId = (*cit).second;
+		pMouse->unregisterListener(iListenerId);
 	}
+	m_mMouseListenerIds.clear();
 	
 	if (m_iDocListenerId != 0)
 		m_pDoc->removeListener(m_iDocListenerId);
 	m_iDocListenerId = 0;
-	
-	
+
 	DELETEP(m_pRecorder);
 }
 
@@ -288,32 +277,32 @@ void AbiCollab::setAcl(const std::vector<std::string> vAcl)
 	m_vAcl = vAcl;
 }
 
-void AbiCollab::_setDocument(PD_Document* pDoc, XAP_Frame* pFrame)
+void AbiCollab::_setDocument(PD_Document* pDoc)
 {
 	UT_DEBUGMSG(("AbiCollab::setDocument()\n"));
 	UT_return_if_fail(pDoc);
-	UT_return_if_fail(pFrame);
 
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_if_fail(pManager);
 
 	// assume clean state
 	UT_return_if_fail(m_iDocListenerId==0);
-
-	// update the frame
 	m_pDoc = pDoc;
 
-	// register ourselves as a mouse listener
-	// FIXME: we should do this for all frames that display this document!
-	EV_Mouse* pMouse = pFrame->getMouse();
-	if (pMouse)
-    {
-		m_iMouseLID = pMouse->registerListener(this);
-    }
-	else
-    {
-		UT_DEBUGMSG(("No current frame!\n"));
-    }
+	// register ourselves as a mouse listener to all frames showing this document
+	for (UT_sint32 i = 0; i < XAP_App::getApp()->getFrameCount(); i++)
+	{
+		XAP_Frame* pFrame = XAP_App::getApp()->getFrame(i);
+		UT_continue_if_fail(pFrame);
+
+		if (pFrame->getCurrentDoc() == m_pDoc)
+		{
+			// this frame is showing our document, attach a mouse listener to it
+			EV_Mouse* pMouse = pFrame->getMouse();
+			if (pMouse)
+				m_mMouseListenerIds[pMouse] = pMouse->registerListener(this);
+		}
+	}
 
 	// add the new export listeners
 	UT_uint32 lid = 0;
@@ -538,6 +527,7 @@ void AbiCollab::addChangeAdjust(ChangeAdjust* pAdjust)
 void AbiCollab::initiateSessionTakeover(BuddyPtr pNewMaster)
 {
 	UT_return_if_fail(pNewMaster);
+	UT_DEBUGMSG(("AbiCollab::initiateSessionTakeover() - pNewMaster: %s\n", pNewMaster->getDescriptor(true).utf8_str()));
 
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_if_fail(pManager);
@@ -664,6 +654,12 @@ void AbiCollab::signalMouse(EV_EditBits eb, UT_sint32 /*xPos*/, UT_sint32 /*yPos
 	}
 }
 
+void AbiCollab::removeMouse(EV_Mouse* pMouse)
+{
+	UT_return_if_fail(pMouse);
+	m_mMouseListenerIds.erase(pMouse);
+}
+
 void AbiCollab::_releaseMouseDrag()
 {
 	m_bDoingMouseDrag = false;
