@@ -106,8 +106,7 @@ public:
 	AbiCollab(PD_Document* pDoc,
 					const UT_UTF8String& sSessionId, 
 					AccountHandler* pAclAccount,
-					bool bLocallyOwned,
-					XAP_Frame* pFrame);
+					bool bLocallyOwned);
 
 	// slave constructor
 	AbiCollab(const UT_UTF8String& sSessionId, 
@@ -116,8 +115,7 @@ public:
 					UT_sint32 iRev,
 					BuddyPtr pControler,
 					AccountHandler* pAclAccount,
-					bool m_bLocallyOwned,
-					XAP_Frame* pFrame);
+					bool m_bLocallyOwned);
 
 	virtual ~AbiCollab();
 
@@ -156,8 +154,6 @@ public:
 	// document management
 	PD_Document*						getDocument(void) const
 		{ return m_pDoc; }
-	XAP_Frame*							getFrame(void) const
-		{ return m_pFrame; }
 
 	const UT_UTF8String					getSessionId() const
 		{ return m_sId; }
@@ -178,6 +174,7 @@ public:
 
 	// mouse listener functionality
 	virtual void						signalMouse(EV_EditBits eb, UT_sint32 xPos, UT_sint32 yPos);
+	virtual void						removeMouse(EV_Mouse* pMouse);
 
 protected:
 	// TODO: make all Packets shared pointers, so this isn't needed anymore
@@ -202,7 +199,7 @@ private:
 
 
 	// document management
-	void								_setDocument(PD_Document* pDoc, XAP_Frame* pFrame);
+	void								_setDocument(PD_Document* pDoc);
 	void								_setDocListenerId(UT_uint32 iDocListenerId)
 		{ m_iDocListenerId = iDocListenerId; }
 	
@@ -225,7 +222,6 @@ private:
 	void								_pushOutgoingQueue();
 
 	PD_Document *						m_pDoc;
-	XAP_Frame*							m_pFrame;
 	ABI_Collab_Import					m_Import;
 	ABI_Collab_Export					m_Export;
 
@@ -249,8 +245,9 @@ private:
 	
 	SessionRecorderInterface*			m_pRecorder;
 
-	UT_sint32							m_iMouseLID;
+	std::map<EV_Mouse*, UT_sint32>		m_mMouseListenerIds;
 	bool								m_bDoingMouseDrag;
+
 	std::vector<std::pair<SessionPacket*,BuddyPtr> >
 										m_vIncomingQueue;
 
