@@ -1453,7 +1453,23 @@ void s_DocBook_Listener::_handleImage(PT_AttrPropIndex api)
 		const gchar* dataid = g_strdup(szValue);
 		char * temp = _stripSuffix(UT_go_basename(szValue), '_');
 		char * fstripped = _stripSuffix(temp, '.');
-		UT_UTF8String_sprintf(buf, "%s.png", fstripped);
+
+        std::string mimeType;
+        const UT_ByteBuf * pByteBuf = 0;
+        const char * extension = "png";
+        const char * format = "PNG";
+        m_pDocument->getDataItemDataByName(szValue, &pByteBuf, 
+                                           &mimeType, NULL);
+        if(mimeType == "image/jpeg") {
+            extension = "jpg";
+            format = "JPEG";
+        }
+        else if(mimeType == "image/svg+xml") {
+            extension = "svg";
+            format = "SVG";
+        }
+
+		UT_UTF8String_sprintf(buf, "%s.%s", fstripped, extension);
 		m_utvDataIDs.push_back(dataid);
 
 		FREEP(temp);
@@ -1483,7 +1499,9 @@ void s_DocBook_Listener::_handleImage(PT_AttrPropIndex api)
 		escaped += UT_go_basename(m_pie->getFileName());
 		escaped += "_data/";
 		escaped += buf.escapeXML();
-		escaped += "\" format=\"PNG\"";
+		escaped += "\" format=\"";
+        escaped += format;
+        escaped += "\"";
 
 		if(pAP->getProperty("height", szValue))
 		{
@@ -1530,7 +1548,23 @@ void s_DocBook_Listener::_handlePositionedImage(PT_AttrPropIndex api)
 		const gchar* dataid = g_strdup(szValue);
 		char * temp = _stripSuffix(UT_go_basename(szValue), '_');
 		char * fstripped = _stripSuffix(temp, '.');
-		UT_UTF8String_sprintf(buf, "%s.png", fstripped);
+
+        std::string mimeType;
+        const UT_ByteBuf * pByteBuf = 0;
+        const char * extension = "png";
+        const char * format = "PNG";
+        m_pDocument->getDataItemDataByName(szValue, &pByteBuf, 
+                                           &mimeType, NULL);
+        if(mimeType == "image/jpeg") {
+            extension = "jpg";
+            format = "JPEG";
+        }
+        else if(mimeType == "image/svg+xml") {
+            extension = "svg";
+            format = "SVG";
+        }
+
+		UT_UTF8String_sprintf(buf, "%s.%s", fstripped, extension);
 		m_utvDataIDs.push_back(dataid);
 
 		FREEP(temp);
@@ -1560,7 +1594,9 @@ void s_DocBook_Listener::_handlePositionedImage(PT_AttrPropIndex api)
 		escaped += UT_go_basename(m_pie->getFileName());
 		escaped += "_data/";
 		escaped += buf.escapeXML();
-		escaped += "\" format=\"PNG\"";
+		escaped += "\" format=\"";
+        escaped += format;
+        escaped += "\"";
 
 		if(pAP->getProperty("frame-height", szValue))
 		{
@@ -2201,10 +2237,11 @@ void s_DocBook_Listener::_handleDataItems(void)
 {
 	// Lifted from HTML listener
  	const char * szName = 0;
-	const char * szMimeType = 0;
+    std::string mimeType;
 	const UT_ByteBuf * pByteBuf;
 	
-	for (UT_uint32 k=0; (m_pDocument->enumDataItems(k,NULL,&szName,&pByteBuf,reinterpret_cast<const void **>(&szMimeType))); k++)
+	for (UT_uint32 k=0; (m_pDocument->enumDataItems(k,NULL,&szName,&pByteBuf,
+                                                    &mimeType)); k++)
 	{
 		UT_sint32 loc = -1;
 		for (UT_sint32 i = 0; i < m_utvDataIDs.getItemCount(); i++)
@@ -2224,16 +2261,20 @@ void s_DocBook_Listener::_handleDataItems(void)
 			/* int result = */
 			UT_go_directory_create(fname.utf8_str(), 0750, NULL);
 			
-			if (!strcmp(szMimeType, "image/svg+xml"))
+			if (mimeType == "image/svg+xml")
 				UT_UTF8String_sprintf(fname, "%s/%s_%d.svg", fname.utf8_str(), szName, loc);
-			if (!strcmp(szMimeType, "application/mathml+xml"))
+			else if (mimeType == "application/mathml+xml")
 				UT_UTF8String_sprintf(fname, "%s/%s_%d.mathml", fname.utf8_str(), szName, loc);
 			else // PNG Image
 			{  
 			  char * temp = _stripSuffix(UT_go_basename(szName), '_');
 			  char * fstripped = _stripSuffix(temp, '.');
 			  FREEP(temp);
-			  UT_UTF8String_sprintf(fname, "%s/%s.png", fname.utf8_str(), fstripped);
+              const char * extension = "png";
+              if (mimeType == "image/jpeg") {
+                  extension = "jpg";
+              }
+			  UT_UTF8String_sprintf(fname, "%s/%s.%s", fname.utf8_str(), fstripped, extension);
 			  FREEP(fstripped);
 			}
 			
