@@ -337,9 +337,6 @@ protected:
 	void				_handleDataItems(void);
 	void				_convertFontSize(UT_String& szDest, const char* pszFontSize);
 	void				_convertColor(UT_String& szDest, const char* pszColor);
-	void				_writeImage (const UT_ByteBuf * pByteBuf,
-								   const UT_UTF8String & imagedir,
-								   const UT_UTF8String & filename);
 	void				_handleImage(const PP_AttrProp * pAP);
 	
 	PD_Document *		m_pDocument;
@@ -1612,7 +1609,8 @@ bool s_LaTeX_Listener::convertMathMLtoLaTeX(const UT_UTF8String & sMathML,
 			return false;
 		}
 	}
-	doc = xmlParseDoc((const xmlChar*)(sMathML.utf8_str()));
+	// bad bad bad, apparently on MacOS X, the system libxml2 take a non-const here.
+	doc = xmlParseDoc((xmlChar*)(sMathML.utf8_str()));
 	if (!doc)
 	{
 		xxx_UT_DEBUGMSG(("convertMathMLtoLaTeX: Parsing MathML document failed\n"));
@@ -2012,59 +2010,44 @@ void s_LaTeX_Listener::_handleDataItems(void)
 }
 
 
-/* Code taken from the HTML exporter
- *
- * imagedir is the name of the directory in which we'll write the image
- * filename is the name of the file to which we'll write the image
- */
-void s_LaTeX_Listener::_writeImage (const UT_ByteBuf * pByteBuf,
-									const UT_UTF8String & imagedir,
-									const UT_UTF8String & filename)
-{
-	UT_go_directory_create(imagedir.utf8_str(), 0750, NULL);
-
-	UT_UTF8String path(imagedir);
-	path += "/";
-	path += filename;
-
-	GsfOutput * out = UT_go_file_create (path.utf8_str (), NULL);
-	if (out)
-	{
-		gsf_output_write (out, pByteBuf->getLength (), (const guint8*)pByteBuf->getPointer (0));
-		gsf_output_close (out);
-		g_object_unref (G_OBJECT (out));
-	}
-}
 
 void s_LaTeX_Listener::_handleImage(const PP_AttrProp * pAP)
 {	
 	/* Part of code taken from the HTML exporter */
 	const UT_ByteBuf * pByteBuf;
 	UT_ByteBuf decodedByteBuf;				
-	const gchar *szHeight = NULL, *szWidth = NULL, *szDataID = NULL, *szMimeType = NULL;
+	const gchar *szHeight = NULL, *szWidth = NULL, *szDataID = NULL;
+    std::string mimeType;
 	
 	if (! pAP)
 		return;
 	if (! pAP->getAttribute("dataid", szDataID))
 		return;
 
-	if (! m_pDocument->getDataItemDataByName(szDataID, &pByteBuf, reinterpret_cast<const void**>(&szMimeType), NULL))
+	if (! m_pDocument->getDataItemDataByName(szDataID, &pByteBuf,
+                                             &mimeType, NULL))
 		return;
-	if ((pByteBuf == 0) || (szMimeType == 0)) return; // ??
+	if ((pByteBuf == 0) || (mimeType.empty())) 
+        return; // ??
 
-	if (strcmp (szMimeType, "image/png") != 0)
+    const char * extension = ".png";
+    if(mimeType == "image/jpeg")
+    {
+        extension = ".jpg";
+    }
+	else if (mimeType != "image/png")
 	{
-		UT_DEBUGMSG(("Object not of MIME type image/png - ignoring...\n"));
+		UT_DEBUGMSG(("Object not of MIME type image/png or image/jpeg but %s - ignoring...\n", mimeType.c_str()));
 		return;
 	}
 
 	gchar *imagedir = UT_go_dirname_from_uri(m_pie->getFileName(), true);
 	
-	UT_UTF8String filename(szDataID);
-	filename += ".png";
+    std::string filename(szDataID);
+	filename += extension;
 	
 	/* save the image as imagedir/filename */
-	_writeImage (pByteBuf, imagedir, filename);
+	IE_Exp::writeBufferToFile(pByteBuf, imagedir, filename);
 	FREEP(imagedir);
 	
 	m_pie->write("\\includegraphics");
@@ -2078,7 +2061,7 @@ void s_LaTeX_Listener::_handleImage(const PP_AttrProp * pAP)
 	}
 
 	m_pie->write("{");
-	m_pie->write(szDataID);
+	m_pie->write(filename.c_str());
 	m_pie->write("}\n");
 
 	return;	
