@@ -459,7 +459,8 @@ ODi_ListenerState* ODi_StreamListener::_createState(const char* pStateName) {
         pState = new ODi_ContentStream_ListenerState(m_pAbiDocument, m_pGsfInfile,
                                                     m_pStyles,
                                                     m_fontFaceDecls,
-                                                    *m_pElementStack);
+						     *m_pElementStack,
+						     m_rAbiData);
 
     } else if (!strcmp("TextContent", pStateName)) {
         
