@@ -114,6 +114,7 @@ enum OXMLi_Keyword
 	KEYWORD_bibliography,
 	KEYWORD_bidi,
 	KEYWORD_bidiVisual,
+	KEYWORD_blipFill,
 	KEYWORD_blockQuote,
 	KEYWORD_body,
 	KEYWORD_bodyDiv,
@@ -164,6 +165,8 @@ enum OXMLi_Keyword
 	KEYWORD_continuationSeparator,
 	KEYWORD_control,
 	KEYWORD_convMailMergeEsc,
+	KEYWORD_cNvPicPr,
+	KEYWORD_cNvPr,
 	KEYWORD_cr,
 	KEYWORD_cs,
 	KEYWORD_customXml,
@@ -431,6 +434,7 @@ enum OXMLi_Keyword
 	KEYWORD_numRestart,
 	KEYWORD_numStart,
 	KEYWORD_numStyleLink,
+	KEYWORD_nvPicPr,
 	KEYWORD_object,
 	KEYWORD_odso,
 	KEYWORD_oMath,
@@ -453,6 +457,7 @@ enum OXMLi_Keyword
 	KEYWORD_pgNum,
 	KEYWORD_pgNumType,
 	KEYWORD_pgSz,
+	KEYWORD_pic,
 	KEYWORD_pict,
 	KEYWORD_picture,
 	KEYWORD_pitch,
@@ -543,6 +548,7 @@ enum OXMLi_Keyword
 	KEYWORD_spacingInWholePoints,
 	KEYWORD_specVanish,
 	KEYWORD_splitPgBreakAndParaMark,
+	KEYWORD_spPr,
 	KEYWORD_src,
 	KEYWORD_start,
 	KEYWORD_startOverride,
