@@ -2,7 +2,7 @@
 
 /* AbiSource Program Utilities
  * Copyright (C) 1998-2000 AbiSource, Inc.
- * Copyright (C) 2001-2004, 2007 Hubert Figuiere
+ * Copyright (C) 2001-2004, 2007, 2009 Hubert Figuiere
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,9 +29,7 @@
 
 #include "ut_types.h"
 #include "ut_debugmsg.h"
-#include "ut_exception.h"
 #include "ut_string.h"
-#include "ut_string_class.h"
 
 #include "xap_CocoaApp.h"
 #include "xap_CocoaFrame.h"
@@ -87,7 +85,7 @@ bool EV_CocoaMenuPopup::synthesizeMenuPopup()
 	return true;
 }
 
-bool EV_CocoaMenuPopup::refreshMenu(AV_View * pView)
+bool EV_CocoaMenuPopup::refreshMenu(AV_View * /*pView*/)
 {
 	return true;
 }
@@ -319,6 +317,7 @@ bool EV_CocoaMenuPopup::refreshMenu(AV_View * pView)
 
 - (BOOL)validateMenuItem:(id <NSMenuItem>)menuItem
 {
+	UT_UNUSED(menuItem);
 	return XAP_App::getApp()->getLastFocussedFrame() ? YES : NO;
 }
 
@@ -829,7 +828,7 @@ NSMenu * EV_CocoaMenu::MenuStack_pop()
 	return menu;
 }
 
-bool EV_CocoaMenu::_doAddMenuItem(UT_uint32 layout_pos)
+bool EV_CocoaMenu::_doAddMenuItem(UT_uint32 /*layout_pos*/)
 {
 	return false;
 }
