@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiSource Program Utilities
  * Copyright (C) 1998 AbiSource, Inc.
  * 
@@ -19,8 +21,11 @@
 
 #define WIN32_LEAN_AND_MEAN
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <windows.h>
-#define _WIN32_IE 0x0300 // specify minimal comctl.dll v4.70 for toolbars
 #include <commctrl.h>   // includes the common control header
 
 #include "ut_assert.h"
@@ -74,7 +79,7 @@
 // This one should really be in the anonymous namespace in this translation
 // unit, but since we don't use namespaces...
 //
-class foo_Bitmap_container
+class ABI_EXPORT foo_Bitmap_container
 {
 public:	// d'tor needs to be public due to buggy MSVC compilers
 	~foo_Bitmap_container();
@@ -138,7 +143,7 @@ EV_Win32Toolbar::~EV_Win32Toolbar(void)
 	if (m_pFontCtrl)
 		delete m_pFontCtrl;
 
-	for (UT_uint32 c=0; c < m_vecOrgStylesNames.getItemCount(); c++)	
+	for (UT_sint32 c=0; c < m_vecOrgStylesNames.getItemCount(); c++)	
 		delete m_vecOrgStylesNames.getNthItem(c);
 
 }
@@ -256,6 +261,14 @@ WHICHPROC s_lpfnDefToolBar;
 LRESULT CALLBACK EV_Win32Toolbar::_ToolBarWndProc (HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM lParam)
 {
 	if (uMessage == WM_CTLCOLORSTATIC) {
+		if(SetBkColor((HDC) wParam, GetSysColor(COLOR_WINDOW)) == CLR_INVALID)
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+		}
+		if(SetTextColor((HDC) wParam, GetSysColor(COLOR_WINDOWTEXT)) == CLR_INVALID)
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+		}
 		return (LRESULT) GetSysColorBrush (COLOR_WINDOW);
 	}
 	
@@ -1105,7 +1118,9 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 					case AP_TOOLBAR_ID_FMT_FONT:
 						idx = SendMessage(hwndCombo, WM_SETTEXT, (WPARAM)-1, (LPARAM)pLocalised);
 						if (idx == CB_ERR)
+						{
 							UT_DEBUGMSG(("refreshToolbar: Failed to set text for font combo.\n"));
+						}
 						break;
 					/* 
 					 * If this is the zoom combo, select the "Other..." string.
@@ -1222,7 +1237,8 @@ int EV_Win32Toolbar::_getBandForHwnd(HWND hToolbar) const
 	HWND hRebar = static_cast<XAP_Win32FrameImpl*>(m_pWin32Frame->getFrameImpl())->getToolbarWindow();
 
 	// If we ever get more than 20 toolbars I don't wanna be around.
-	REBARBANDINFO rbi = { 0 };
+	REBARBANDINFO rbi;
+	memset(&rbi, 0, sizeof(rbi));
 	rbi.cbSize = sizeof(rbi);
 	rbi.fMask  = RBBIM_CHILD;
 	for (int i = 0; i < 20; ++i)
@@ -1250,7 +1266,8 @@ void EV_Win32Toolbar::_addToRebar()
 	UINT iWidth = rc.right - rc.left + 13;
 
 	// add this bar to the rebar
-	REBARBANDINFO  rbbi = { 0 };
+	REBARBANDINFO  rbbi;
+	memset(&rbbi, 0, sizeof(rbbi));
 	// Initialize REBARBANDINFO
 	rbbi.cbSize = sizeof(REBARBANDINFO);
 	rbbi.fMask =	RBBIM_COLORS	|	// clrFore and clrBack are valid
@@ -1349,13 +1366,13 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 	UT_UTF8String utf8;
 	UT_String str;
 
-	for (UT_uint32 c=0; c < m_vecOrgStylesNames.getItemCount(); c++)	
+	for (UT_sint32 c=0; c < m_vecOrgStylesNames.getItemCount(); c++)	
 		delete m_vecOrgStylesNames.getNthItem(c);
 
 	m_vecOrgStylesNames.clear();
 	
 	
-	for (UT_uint32 k=0; k < v->getItemCount(); k++)
+	for (UT_sint32 k=0; k < v->getItemCount(); k++)
 	{
 		const char*	sz = (char *)v->getNthItem(k);
 		const char*	pLocalised = sz;
