@@ -22,12 +22,15 @@
 #ifndef EV_MOUSELISTENER_H
 #define EV_MOUSELISTENER_H
 
+class EV_Mouse;
+
 class ABI_EXPORT EV_MouseListener
 {
 public:
 	virtual ~EV_MouseListener() {}
 	// coordinates are in layout units
 	virtual void signalMouse(EV_EditBits eb, UT_sint32 xPos, UT_sint32 yPos) = 0;
+	virtual void removeMouse(EV_Mouse* pMouse) = 0;
 };
 
 #endif /* EV_MOUSELISTENER_H */
