@@ -29,6 +29,25 @@
 #include "xap_App.h"
 #include "xap_EncodingManager.h"
 
+#define GTK_CHECK_VERSION(major,minor,micro) \
+	(GTK_MAJOR_VERSION > (major) || \
+	(GTK_MAJOR_VERSION == (major) && GTK_MINOR_VERSION > (minor)) || \
+	(GTK_MAJOR_VERSION == (major) && GTK_MINOR_VERSION == (minor) && \
+	GTK_MICRO_VERSION >= (micro)))
+
+// remove this define and our own gdk_cairo_reset_clip function when gtk 2.18 is released
+#define GTK_2_17_DEV_VERSION_WITHOUT_RESET_CLIP \
+	(GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION == 17 && \
+    (GTK_MICRO_VERSION >= 0 && GTK_MICRO_VERSION <= 10))
+
+#if GTK_2_17_DEV_VERSION_WITHOUT_RESET_CLIP
+void gdk_cairo_reset_clip (cairo_t *cr, GdkDrawable *drawable)
+{
+	cairo_reset_clip (cr);
+	if (GDK_DRAWABLE_GET_CLASS (drawable)->set_cairo_clip)
+		GDK_DRAWABLE_GET_CLASS (drawable)->set_cairo_clip (drawable, cr);
+}
+#endif
 
 GR_UnixCairoGraphicsBase::~GR_UnixCairoGraphicsBase()
 {
@@ -124,6 +143,26 @@ inline UT_RGBColor _convertGdkColor(const GdkColor &c)
 	return color;
 }
 
+void GR_UnixCairoGraphics::widget_size_allocate(GtkWidget* /*widget*/, GtkAllocation* /*allocation*/, GR_UnixCairoGraphics* me)
+{
+#if GTK_CHECK_VERSION(2,17,11) || GTK_2_17_DEV_VERSION_WITHOUT_RESET_CLIP
+	UT_return_if_fail(me);
+	me->m_clipRectDirty = TRUE;
+#else
+	UT_UNUSED(me);
+#endif
+}
+
+void GR_UnixCairoGraphics::initWidget(GtkWidget* widget)
+{
+#if GTK_CHECK_VERSION(2,17,11) || GTK_2_17_DEV_VERSION_WITHOUT_RESET_CLIP
+	UT_return_if_fail(widget);
+	g_signal_connect_after(G_OBJECT(widget), "size_allocate", G_CALLBACK(widget_size_allocate), this);
+#else
+	UT_UNUSED(widget);
+#endif
+}
+
 void GR_UnixCairoGraphics::init3dColors(GtkStyle * pStyle)
 {
 	m_3dColors[CLR3D_Foreground] = _convertGdkColor(pStyle->text[GTK_STATE_NORMAL]);
@@ -359,6 +398,14 @@ void GR_UnixCairoGraphics::createPixmapFromXPM( char ** pXPM,GdkPixmap *source,
 							pXPM);
 }
 
+void GR_UnixCairoGraphics::_resetClip(void)
+{
+#if GTK_CHECK_VERSION(2,17,11) || GTK_2_17_DEV_VERSION_WITHOUT_RESET_CLIP
+	gdk_cairo_reset_clip (m_cr, _getDrawable());
+#else
+	cairo_reset_clip (m_cr);
+#endif
+}
 
 void GR_UnixCairoGraphics::saveRectangle(UT_Rect & r, UT_uint32 iIndx)
 {
