@@ -413,7 +413,7 @@ bool UT_getEthernetAddress(UT_EthernetAddress &A)
     Class that implements an assert dialogue; this is a private class, we only access it
     through UT_Win32ThrowAssert() function
 */
-class UT_Win32AssertDlg
+class ABI_EXPORT UT_Win32AssertDlg
 {
 	friend int ABI_EXPORT UT_Win32ThrowAssert(const char *, const char *, int, int);
 	
@@ -514,7 +514,7 @@ UT_Win32AssertDlg::answer UT_Win32AssertDlg::runModal()
 	return m_answer;
 }
 
-BOOL UT_Win32AssertDlg::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam)
+BOOL UT_Win32AssertDlg::_onCommand(HWND hWnd, WPARAM wParam, LPARAM /*lParam*/)
 {
 	WORD wId = LOWORD(wParam);
 	
@@ -563,7 +563,7 @@ BOOL CALLBACK UT_Win32AssertDlg::s_DisableWindows(HWND hwnd,	LPARAM lParam)
 
 void UT_Win32AssertDlg::enableWindows()
 {
-	for(UT_uint32 i = 0; i < m_vecDisabledWnds.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vecDisabledWnds.getItemCount(); i++)
 	{
 		EnableWindow(m_vecDisabledWnds.getNthItem(i), TRUE);
 	}
@@ -571,7 +571,7 @@ void UT_Win32AssertDlg::enableWindows()
 	m_vecDisabledWnds.clear();
 }
 
-BOOL UT_Win32AssertDlg::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam)
+BOOL UT_Win32AssertDlg::_onInitDialog(HWND hWnd, WPARAM /*wParam*/, LPARAM lParam)
 {
 	// pause all timers
 	m_bTimersPaused = UT_Win32Timer::timersPaused();
