@@ -31,6 +31,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h> // this include seems to fix 12332 (it defines GDK_Escape)
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -160,17 +161,11 @@ static void s_filetypechanged(GtkWidget * w, gpointer p)
 static gint
 fsel_key_event (GtkWidget * widget, GdkEventKey * event, XAP_Dialog_FileOpenSaveAs::tAnswer * answer)
 {
-#ifdef GDK_Escape
 	if (event->keyval == GDK_Escape) {
 		g_signal_stop_emission_by_name (G_OBJECT (widget), "key_press_event");
 		s_dialog_response(widget, GTK_RESPONSE_CANCEL, answer);
 		return TRUE;
 	}
-#else
-	UT_UNUSED(widget);
-	UT_UNUSED(event);
-	UT_UNUSED(answer);
-#endif
 
 	return FALSE;
 }
@@ -477,7 +472,7 @@ void XAP_UnixDialog_FileOpenSaveAs::fileTypeChanged(GtkWidget * w)
 
 void XAP_UnixDialog_FileOpenSaveAs::onDeleteCancel() 
 {
-	if (GTK_HAS_GRAB) {
+	if (m_FC != NULL && GTK_WIDGET_HAS_GRAB(GTK_WIDGET (m_FC))) {
 		gtk_grab_remove (GTK_WIDGET (m_FC));
 	}
 	m_FC = NULL;
