@@ -156,7 +156,10 @@ void fl_AutoNum::fixHierarchy(void)
 	{
 		PL_StruxDocHandle sdh = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(0));
 		XAP_Frame * pFrame = XAP_App::getApp()->getLastFocussedFrame();
-		FV_View * pView = static_cast<FV_View *>(pFrame->getCurrentView());
+		FV_View* pView = NULL;
+		if (pFrame)
+			pView = static_cast<FV_View *>(pFrame->getCurrentView());
+
 		bool bFound = m_pDoc->getAttributeFromSDH(sdh,
 												  pView ? pView->isShowRevisions() : true,
 												  pView ? pView->getRevisionLevel(): PD_MAX_REVISION,
@@ -853,7 +856,7 @@ UT_uint32 fl_AutoNum::getNumLabels() const
 
 UT_sint32 fl_AutoNum::getPositionInList(PL_StruxDocHandle pItem, UT_uint32 /*depth*/) const
 {
-	UT_ASSERT(m_pItems.getItemCount() > 0);
+	UT_return_val_if_fail(m_pItems.getItemCount() >= 0, -1)
 
 	PL_StruxDocHandle pTmp;
 	UT_uint32 ndx = 0;
