@@ -85,6 +85,7 @@ class fl_EndnoteLayout;
 class fp_EndnoteContainer;
 class GR_EmbedManager;
 class fl_FrameLayout;
+class fp_Container;
 
 // the following get used by view and layout code, 
 // since they're private to the formatter, we stick 'em here
@@ -109,6 +110,8 @@ public:
 	~FL_DocLayout();
 
 	void fillLayouts(void);
+	bool loadPendingObjects(void);
+	bool AnchoredObjectHelper(double x, double y, UT_sint32 iPage, UT_UTF8String & allProps, PT_DocPosition & pos, fp_Page *& pPage);
 	void setView(FV_View*);
 
 	inline FV_View * getView(void) const { return m_pView; }
@@ -140,6 +143,7 @@ public:
 	void			notifyBlockIsBeingDeleted(fl_BlockLayout *pBlock);
 	void            setSkipUpdates(UT_uint32 numSkips) {m_iSkipUpdates = numSkips;}
 	UT_uint32       getSkipUpdates(void) { return m_iSkipUpdates;}
+	void            setNeedsRedraw(void);
 	UT_sint32		getHeight();
 	UT_sint32       getWidth();
 	void            refreshRunProperties(void);
@@ -165,6 +169,7 @@ public:
 	UT_sint32   findPage(fp_Page * pPage);
 	void            setFramePageNumbers(UT_sint32 iStartPage);
 	void            relocateFrame(fl_FrameLayout * pFrame);
+	void            clearAllCountWraps(void);
 
 	UT_sint32   getPercentFilled(void)
 		{ return m_iFilled;}
@@ -355,6 +360,10 @@ public:
 	GR_EmbedManager * getQuickPrintEmbedManager(const char * szEmbedType);
 	fp_PageSize	m_docViewPageSize;
 	bool            setDocViewPageSize(const PP_AttrProp * pAP);
+        void            setSaveContainerPointer( fp_Container * pContainer);
+	void            setRebuiltBlock(fl_BlockLayout *pBlock);
+	fl_BlockLayout* getRebuiltBlock(void);
+	fp_Container *  getSavedContainerPointer(void);
 
 #ifdef FMT_TEST
 	//! Pointer to last instatiated FL_DocLayout. Used for debugging.
@@ -442,6 +451,8 @@ private:
 	GR_Graphics *       m_pQuickPrintGraphics;
 	bool                m_bIsQuickPrint;
 	bool                m_bDisplayAnnotations;
+        fp_Container *      m_pSavedContainer;
+	fl_BlockLayout *    m_pRebuiltBlockLayout;
 };
 
 #endif /* DOCLAYOUT_H */
