@@ -70,7 +70,6 @@ static void s_background_properties (const gchar * pszBgStyle, const gchar * psz
 
 
 fl_FrameLayout::fl_FrameLayout(FL_DocLayout* pLayout, 
-							   fl_DocSectionLayout* pDocSL, 
 							   PL_StruxDocHandle sdh, 
 							   PT_AttrPropIndex indexAP, 
 							   fl_ContainerLayout * pMyContainerLayout)
@@ -86,7 +85,6 @@ fl_FrameLayout::fl_FrameLayout(FL_DocLayout* pLayout,
 	  m_bNeedsRebuild(false),
 	  m_bNeedsFormat(true),
 	  m_bIsOnPage(false),
-	  m_pDocSL(pDocSL),
 	  m_bHasEndFrame(false),
 	  m_iWidth(0),
 	  m_iHeight(0),
@@ -102,9 +100,10 @@ fl_FrameLayout::fl_FrameLayout(FL_DocLayout* pLayout,
 	  m_iFrameWrapMode(FL_FRAME_ABOVE_TEXT),
 	  m_bIsTightWrap(false),
 	  m_iPrefPage(-1),
-	  m_bRelocate(false)
+	  m_bRelocate(false),
+	  m_bExpandHeight(false),
+	  m_iMinHeight(0)
 {
-	UT_ASSERT(m_pDocSL->getContainerType() == FL_CONTAINER_DOCSECTION);
 }
 
 fl_FrameLayout::~fl_FrameLayout()
@@ -189,12 +188,8 @@ void 	fl_FrameLayout::setContainerProperties(void)
 			UT_sint32 iHeight = pG->tlu(100);
 			if(m_pGraphicImage->getType() == FGT_Raster)
 			{
-				UT_sint32 iImageWidth;
-				UT_sint32 iImageHeight;
-				const UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(m_pGraphicImage)->getRaster_PNG();
-				UT_PNG_getDimensions(pBB, iImageWidth, iImageHeight);
-				iWidth = pG->tlu(iImageWidth);
-				iHeight = pG->tlu(iImageHeight);
+				iWidth = pG->tlu(m_pGraphicImage->getWidth());
+				iHeight = pG->tlu(m_pGraphicImage->getHeight());
 			}
 			GR_Image * pImage = m_pGraphicImage->generateImage(pG,pAP,iWidth,iHeight);
 			m_iDocImageWidth = pFrame->getFullWidth();
@@ -602,6 +597,11 @@ void fl_FrameLayout::_createFrameContainer(void)
 	pSectionAP->getAttribute(PT_STRUX_IMAGE_DATAID, (const gchar *&)pszDataID);
 	DELETEP(m_pGraphicImage);
 	DELETEP(m_pImageImage);
+	//
+	// Set the image size from the full width
+	//
+	setImageWidth(pFrameContainer->getFullWidth());
+	setImageHeight(pFrameContainer->getFullHeight());
 	if(pszDataID && *pszDataID)
 	{
 		UT_DEBUGMSG(("!!!Found image of file %s \n",pszDataID));
@@ -673,7 +673,6 @@ void fl_FrameLayout::format(void)
 		getNewContainer();
 	}
 	fl_ContainerLayout*	pBL2 = getFirstLayout();
-	bool bOnPage = false;
 	while (pBL2)
 	{
 		pBL2->format();
@@ -692,6 +691,7 @@ void fl_FrameLayout::format(void)
 		pBL2 = pBL2->getNext();
 	}
 	static_cast<fp_FrameContainer *>(getFirstContainer())->layout();
+	bool bPlacedOnPage = false;
 	if(!m_bIsOnPage)
 	{
 //
@@ -746,28 +746,33 @@ void fl_FrameLayout::format(void)
 		}
 		if(!pBL->isCollapsed())
 		{
-		  bOnPage = pBL->setFramesOnPage(NULL);
-		  if(!bOnPage)
-		  {
-		    setNeedsReformat(this);
-		  }
+			m_bIsOnPage = pBL->setFramesOnPage(NULL);
+			if(!m_bIsOnPage)
+			{
+				setNeedsReformat(this);
+			}
 		}
+		if(m_bIsOnPage)
+			bPlacedOnPage = true;
 	}
-	m_bNeedsFormat = bOnPage;
-	m_bNeedsReformat = bOnPage;
-	if(!bOnPage)
+	m_bNeedsFormat = m_bIsOnPage;
+	m_bNeedsReformat = m_bIsOnPage;
+	if(!m_bIsOnPage)
 	{
-	  setNeedsReformat(this);
+		setNeedsReformat(this);
 	}
-	if(!bOnPage)
+	if(!m_bIsOnPage)
 	{
-	  return;
+		return;
 	}
-	fl_DocSectionLayout * pDSL = getDocSectionLayout();
-	fp_FrameContainer * pFC = static_cast<fp_FrameContainer *>(getFirstContainer());
-	if(pFC)
+	if(bPlacedOnPage)
 	{
-		pDSL->setNeedsSectionBreak(true,pFC->getPage());
+		fl_DocSectionLayout * pDSL = getDocSectionLayout();
+		fp_FrameContainer * pFC = static_cast<fp_FrameContainer *>(getFirstContainer());
+		if(pFC)
+		{
+			pDSL->setNeedsSectionBreak(true,pFC->getPage());
+		}
 	}
 }
 
@@ -811,6 +816,9 @@ void fl_FrameLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	const gchar * pszTightWrapped = NULL;
 	const gchar * pszPrefPage = NULL;
 
+	const gchar * pszExpandHeight = NULL;
+	const gchar * pszPercentWidth = NULL;
+	const gchar * pszMinHeight = NULL;
 // Frame Type
 
 	if(!pSectionAP || !pSectionAP->getProperty("frame-type",pszFrameType))
@@ -982,7 +990,7 @@ void fl_FrameLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	{
 		m_iXPage = UT_convertToLogicalUnits(pszPageXpos);
 	}
-	UT_DEBUGMSG(("PageXpos for frame is %s \n",pszPageXpos));
+	UT_DEBUGMSG(("PageXpos for frame is %s units %d \n",pszPageXpos,m_iXPage));
 // PageYpos
 
 	if(!pSectionAP || !pSectionAP->getProperty("frame-page-ypos",pszPageYpos))
@@ -993,7 +1001,8 @@ void fl_FrameLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	{
 		m_iYPage = UT_convertToLogicalUnits(pszPageYpos);
 	}
-	UT_DEBUGMSG(("PageYpos for frame is %s units %d \n",pszColYpos,m_iYPage));
+	UT_DEBUGMSG(("PageYpos for frame is %s units %d \n",pszPageYpos,m_iYPage));
+
 
 // Width
 
@@ -1024,6 +1033,7 @@ void fl_FrameLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	{
 		m_iHeight = m_pLayout->getGraphics()->tlu(2);
 	}
+	m_iMinHeight = m_iHeight;
 	UT_DEBUGMSG(("Height %s \n",pszHeight));
 
 // Xpadding
@@ -1132,6 +1142,54 @@ void fl_FrameLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		else
 			m_iPrefPage = -1;
 	}
+
+	// 
+	// Percent Width
+	//
+	if(pSectionAP && pSectionAP->getProperty("frame-rel-width",pszPercentWidth))
+	{
+		if(pszPercentWidth && (m_iWidth <= (m_pLayout->getGraphics()->tlu(2)+3)))
+		{
+			double frac_width = UT_convertFraction(pszPercentWidth);
+			fl_DocSectionLayout * pDSL = getDocSectionLayout();
+			m_iWidth = frac_width*pDSL->getActualColumnWidth();
+		}
+	}
+
+	//
+	// Min Height
+	//
+	if(pSectionAP && pSectionAP->getProperty("frame-min-height",pszMinHeight))
+	{
+		if(pszMinHeight)
+		{
+			m_iMinHeight = UT_convertToLogicalUnits(pszMinHeight);
+			m_bExpandHeight = true;
+		}
+	}
+
+	//
+	// Expandable Height
+	//
+	if(pSectionAP && pSectionAP->getProperty("frame-expand-height",pszExpandHeight))
+	{
+		m_iMinHeight = m_iHeight;
+		m_bExpandHeight = true;
+	}
+
+	//
+	// left/right aligned
+	//
+	const char * pszAlign = NULL;
+	if(pSectionAP && pSectionAP->getProperty("frame-horiz-align",pszAlign))
+	{
+		if(pszAlign && (strcmp(pszAlign,"right") == 0) && (m_iXpos == 0))
+		{
+			fl_DocSectionLayout * pDSL = getDocSectionLayout();
+			m_iXpos =  pDSL->getActualColumnWidth() - m_iWidth;
+		}
+	}
+
 }
 
 void fl_FrameLayout::_lookupMarginProperties(const PP_AttrProp* pSectionAP)
