@@ -70,7 +70,6 @@ class ABI_EXPORT fl_FrameLayout : public fl_SectionLayout
 
 public:
 	fl_FrameLayout(FL_DocLayout* pLayout,
-				   fl_DocSectionLayout * pDocSL, 
 				   PL_StruxDocHandle sdh, 
 				   PT_AttrPropIndex ap, 
 				   fl_ContainerLayout * pMyContainerLayout);
@@ -104,7 +103,6 @@ public:
 	bool                     recalculateFields(UT_uint32 iUpdateCount);
 	virtual void		     redrawUpdate(void);
 	virtual fp_Container*	 getNewContainer(fp_Container* = NULL);
-	fl_DocSectionLayout*	 getDocSectionLayout(void) const { return m_pDocSL; }
 	PT_DocPosition           getDocPosition(void);
 	UT_uint32                getLength(void);
 	virtual void             setNeedsReformat(fl_ContainerLayout * pCL, UT_uint32 offset = 0);
@@ -143,6 +141,10 @@ public:
 	  { return m_bIsTightWrap;}
 	bool                isRelocate(void) const
 	{ return m_bRelocate;}
+	bool                expandHeight(void) const
+	{ return m_bExpandHeight;}
+	UT_sint32           minHeight(void) const
+	{ return m_iMinHeight;}
 private:
 	virtual void		     _lookupProperties(const PP_AttrProp* pAP);
 	virtual void		     _lookupMarginProperties(const PP_AttrProp* pAP);
@@ -154,7 +156,6 @@ private:
 	bool                     m_bNeedsRebuild;
 	bool                     m_bNeedsFormat;
 	bool                     m_bIsOnPage;
-	fl_DocSectionLayout*	 m_pDocSL;
 	bool                     m_bHasEndFrame;
 
 // Frame-background properties
@@ -185,6 +186,8 @@ private:
 	bool                    m_bIsTightWrap;
 	UT_sint32               m_iPrefPage;
 	bool                    m_bRelocate;
+	bool                    m_bExpandHeight;
+	UT_sint32               m_iMinHeight;
 };
 
 #endif /* FRAMELAYOUT_H */
