@@ -96,6 +96,7 @@ struct _fp_Allocation
 class GR_Graphics;
 class FG_Graphic;
 class fl_SectionLayout;
+class fl_DocSectionLayout;
 class FL_DocLayout;
 class fp_Page;
 class fp_Container;
@@ -193,6 +194,7 @@ public:
 	virtual UT_sint32	getY(void) const = 0;
 	fl_SectionLayout*   getSectionLayout(void) const
 		{ return m_pSectionLayout; }
+	fl_DocSectionLayout *   getDocSectionLayout(void);
     void         setSectionLayout(fl_SectionLayout * pSL)
 		{ m_pSectionLayout = pSL; }
 	virtual inline UT_BidiCharType getDirection(void) const
@@ -221,6 +223,10 @@ public:
     virtual UT_Rect *      getScreenRect() = 0;
     virtual void           markDirtyOverlappingRuns(UT_Rect & recScreen) = 0;
 	const char *           getContainerString(void);
+	void                   setAllowDelete(bool bDelete)
+	{ m_bCanDelete = bDelete;}
+	bool                   canDelete(void)
+	{ return m_bCanDelete;}
     UT_sint32   getBreakTick(void) const
 		{ return  m_iBreakTick;}
 	void        setBreakTick(UT_sint32 iTick)
@@ -243,6 +249,7 @@ private:
 	UT_BidiCharType         m_iDirection;
 	UT_sint32               m_iBreakTick;
 	UT_sint32               m_iRef;
+	bool                    m_bCanDelete;
 };
 
 
