@@ -93,7 +93,11 @@ void FV_VisualDragText::setMode(FV_VisualDragMode iEditMode)
 	}
 }
 
-void FV_VisualDragText::_autoScroll(UT_Worker * pWorker)
+static UT_sint32 iExtra = 0;
+static bool bScrollRunning = false;
+static UT_Worker * s_pScroll = NULL;
+
+void FV_VisualDragText::_actuallyScroll(UT_Worker * pWorker)
 {
 	UT_return_if_fail(pWorker);
 
@@ -127,15 +131,24 @@ void FV_VisualDragText::_autoScroll(UT_Worker * pWorker)
 	{
 		bScrollRight = true;
 	}
+
 	if(bScrollDown || bScrollUp || bScrollLeft || bScrollRight)
 	{
+	        UT_sint32 minScroll = pView->getGraphics()->tlu(20);
+
 		if(bScrollUp)
 		{
-			pView->cmdScroll(AV_SCROLLCMD_LINEUP, static_cast<UT_uint32>( -y));
+		        UT_sint32 yscroll = abs(y);
+			if(yscroll < minScroll)
+			    yscroll = minScroll;
+			pView->cmdScroll(AV_SCROLLCMD_LINEUP, static_cast<UT_uint32>( yscroll) + iExtra);
 		}
 		else if(bScrollDown)
 		{
-			pView->cmdScroll(AV_SCROLLCMD_LINEDOWN, static_cast<UT_uint32>(y - pView->getWindowHeight()));
+		        UT_sint32 yscroll = y - pView->getWindowHeight();
+			if(yscroll < minScroll)
+			    yscroll = minScroll;
+			pView->cmdScroll(AV_SCROLLCMD_LINEDOWN, static_cast<UT_uint32>(yscroll) + iExtra);
 		}
 		if(bScrollLeft)
 		{
@@ -151,17 +164,61 @@ void FV_VisualDragText::_autoScroll(UT_Worker * pWorker)
 		pView->_setPoint(posAtXY);
 		pVis->drawCursor(posAtXY);
 #endif
+		iExtra = 0;
 		return;
 	}
 	else
 	{
-		pVis->m_pAutoScrollTimer->stop();
+		if(pVis->m_pAutoScrollTimer)
+			pVis->m_pAutoScrollTimer->stop();
 		DELETEP(pVis->m_pAutoScrollTimer);
 	}
+	s_pScroll->stop();
+	delete s_pScroll;
+	s_pScroll = NULL;
+	bScrollRunning = false;
+	iExtra = 0;
 
 }
 
+void FV_VisualDragText::_autoScroll(UT_Worker * pWorker)
+{
+
+	// this is a static callback method and does not have a 'this' pointer.
+
+	UT_return_if_fail(pWorker);
+	FV_VisualDragText * pVis = static_cast<FV_VisualDragText *>(pWorker->getInstanceData());
+	UT_return_if_fail(pVis);
+	if(bScrollRunning)
+	{
+	    UT_DEBUGMSG(("Dropping VisualDragText autoscroll !!!!!!! \n"));
+	    if(iExtra < pVis->getGraphics()->tlu(600))
+	      iExtra += pVis->getGraphics()->tlu(20);
+	    return;
+	}
+
+	int inMode = UT_WorkerFactory::IDLE | UT_WorkerFactory::TIMER;
+	UT_WorkerFactory::ConstructMode outMode = UT_WorkerFactory::NONE;
+	s_pScroll = UT_WorkerFactory::static_constructor (_actuallyScroll,pVis, inMode, outMode);
+
+	// If the worker is working on a timer instead of in the idle
+	// time, set the frequency of the checks.
+	if ( UT_WorkerFactory::TIMER == outMode )
+	{
+		// this is really a timer, so it's safe to static_cast it
+		static_cast<UT_Timer*>(s_pScroll)->set(100);
+	}
+	bScrollRunning = true;
+	iExtra = 0;
+	s_pScroll->start();
+}
+
 void FV_VisualDragText::mouseDrag(UT_sint32 x, UT_sint32 y)
+{
+  _mouseDrag(x,y);
+}
+
+void FV_VisualDragText::_mouseDrag(UT_sint32 x, UT_sint32 y)
 {
  	  //
 	  // Don't try to drag the entire document.
@@ -202,7 +259,6 @@ void FV_VisualDragText::mouseDrag(UT_sint32 x, UT_sint32 y)
 	  else
 	  {
 	    m_iVisualDragMode = FV_VisualDrag_START_DRAGGING;
-
 	    XAP_Frame * pFrame = static_cast<XAP_Frame*>(m_pView->getParentData());
 	    if (pFrame)
 	      pFrame->dragText();
@@ -410,7 +466,7 @@ bool FV_VisualDragText::reposOffsets(UT_sint32 x, UT_sint32 y)
     bAdjustX = true;
     dx -= getGraphics()->tlu(20);
     m_iInitialOffX -= dx;
-    UT_Rect expX(0,m_recCurFrame.top,0,m_recCurFrame.height);
+    expX.set(0,m_recCurFrame.top,0,m_recCurFrame.height);
     m_recCurFrame.left += dx;
     m_recOrigLeft.left += dx;
     m_recOrigRight.left += dx;
@@ -420,7 +476,7 @@ bool FV_VisualDragText::reposOffsets(UT_sint32 x, UT_sint32 y)
     bAdjustY = true;
     dy -= getGraphics()->tlu(20);
     m_iInitialOffY -= dy;
-    UT_Rect expY(m_recCurFrame.left,0,m_recCurFrame.width,0);
+    expY.set(m_recCurFrame.left,0,m_recCurFrame.width,0);
     m_recCurFrame.top += dy;
     m_recOrigLeft.top += dy;
     m_recOrigRight.top += dy;
@@ -504,21 +560,22 @@ void FV_VisualDragText::clearCursor(void)
 	{
 		if(m_pDocUnderCursor)
 		{
+		        getGraphics()->allCarets()->disable(true);
+		        m_pView->m_countDisable++;
 			GR_Painter painter(getGraphics());
-			painter.drawImage(m_pDocUnderCursor,m_recCursor.left,m_recCursor.top);
+			painter.drawImage(m_pDocUnderCursor,m_recDoc.left,m_recCursor.top);
 			m_bCursorDrawn = false;
 			DELETEP(m_pDocUnderCursor);
 		}
-		else
-		{
-			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		}
 	}
 }
 
 void FV_VisualDragText::drawCursor(PT_DocPosition newPos)
 {
-
+        if(m_bCursorDrawn)
+	    return;
+	getGraphics()->allCarets()->disable(true);
+	m_pView->m_countDisable++;
 	fp_Run * pRunLow = NULL;
 	fl_BlockLayout * pBlock = NULL;
 	UT_sint32 xLow, yLow;
@@ -532,9 +589,13 @@ void FV_VisualDragText::drawCursor(PT_DocPosition newPos)
 	m_recCursor.width =  getGraphics()->tlu(2); // the cursor is 2 device units wide, not
 												// logical units
 	m_recCursor.height = heightCaret;
+	m_recDoc.left = xLow - getGraphics()->tlu(1);
+	m_recDoc.top = yLow - getGraphics()->tlu(1);
+	m_recDoc.width =  getGraphics()->tlu(3);
+	m_recDoc.height = heightCaret + getGraphics()->tlu(1);
 	UT_ASSERT(m_pDocUnderCursor == NULL);
 	GR_Painter painter(getGraphics());
-	m_pDocUnderCursor = painter.genImageFromRectangle(m_recCursor);
+	m_pDocUnderCursor = painter.genImageFromRectangle(m_recDoc);
 	UT_RGBColor black(0,0,0);
 	painter.fillRect( black, m_recCursor);
 	m_bCursorDrawn = true;
@@ -748,20 +809,20 @@ void FV_VisualDragText::getImageFromSelection(UT_sint32 x, UT_sint32 y)
 	    //
 	    // Look to see if we have a rectangular table selection
 	    //
-	    UT_sint32 iExtra = 1;
-	    if(m_pView->getDocument()->isTableAtPos(posLow+iExtra))
+	    UT_sint32 nExtra = 1;
+	    if(m_pView->getDocument()->isTableAtPos(posLow+nExtra))
 	    {
-	      iExtra++;
+	      nExtra++;
 	    }
-	    if(m_pView->getDocument()->isCellAtPos(posLow+iExtra))
+	    if(m_pView->getDocument()->isCellAtPos(posLow+nExtra))
 	    {
-	      iExtra++;
+	      nExtra++;
 	    }
-	    if(m_pView->getDocument()->isBlockAtPos(posLow+iExtra))
+	    if(m_pView->getDocument()->isBlockAtPos(posLow+nExtra))
 	    {
-	      iExtra++;
+	      nExtra++;
 	    }
-	    fp_CellContainer * pCellConLow = m_pView->getCellAtPos(posLow+iExtra);
+	    fp_CellContainer * pCellConLow = m_pView->getCellAtPos(posLow+nExtra);
 	    if(pCellConLow == NULL)
 	      goto do_broken;
 	    fl_CellLayout * pCellLow = static_cast<fl_CellLayout *>(pCellConLow->getSectionLayout());
