@@ -24,9 +24,9 @@
 #ifndef PD_DOCUMENT_H
 #define PD_DOCUMENT_H
 
-// TODO should the filename be UT_UCSChar rather than char ?
-
 #include <stdio.h>
+#include <string>
+
 #include "ut_types.h"
 #include "ut_vector.h"
 #include "ut_hash.h"
@@ -61,8 +61,7 @@ class fl_BlockLayout;
 class fp_Run;
 class UT_UTF8String;
 class pp_Author;
-class _ImagePage;
-class _TextboxPage;
+
 
 #ifdef PT_TEST
 #include "ut_test.h"
@@ -157,6 +156,46 @@ enum
 // the creator (product) of this document. AbiWord, KWord, etc...
 #define PD_META_KEY_GENERATOR         "abiword.generator"
 
+class ABI_EXPORT  ImagePage
+{
+public:
+	ImagePage(UT_UTF8String & sImageId, UT_sint32 iPage, double xInch, double yInch, const char * pzProps);
+	virtual ~ImagePage(void);
+	const UT_UTF8String * getImageId(void) const;
+	UT_sint32 getPageNo(void) const;
+	double getXInch(void) const;
+	double getYInch(void) const;
+	const	UT_UTF8String * getProps(void) const;
+
+private:
+	UT_UTF8String m_sImageId;
+	UT_sint32 m_iPage;
+	double m_xInch;
+	double m_yInch;
+	UT_UTF8String m_sProps;
+};
+
+/*!
+ * Helpder class to import Page Referenced TextBoxes
+ */
+class ABI_EXPORT TextboxPage
+{
+public:
+	TextboxPage(UT_sint32 iPage, double xInch, double yInch,const char * pzProps, UT_ByteBuf & sContent);
+	virtual ~TextboxPage(void);
+	const UT_ByteBuf * getContent(void) const;
+	UT_sint32 getPageNo(void) const;
+	double getXInch(void) const;
+	double getYInch(void) const;
+	const UT_UTF8String * getProps(void) const;
+private:
+	UT_sint32 m_iPage;
+	double m_xInch;
+	double m_yInch;
+	UT_UTF8String m_sProps;
+	UT_ByteBuf m_sContent;
+};
+
 
 /*!
  PD_Document is the representation for a document.
@@ -198,6 +237,14 @@ public:
 
 	void                    removeCaret(const std::string& sCaretID);
 
+	// Page Referenced methods
+
+	void                    addPageReferencedImage(UT_UTF8String & sImageId, UT_sint32 iPage, double xInch, double yInch, const char * pzProps);
+	void                    addPageReferencedTextbox(UT_ByteBuf & sContent,UT_sint32 iPage, double xInch, double yInch,const char * pzProps);
+	ImagePage *             getNthImagePage(UT_sint32 iImagePage);
+	TextboxPage *           getNthTextboxPage(UT_sint32 iTextboxPage);
+	void                    clearAllPendingObjects(void);
+
 	// Author methods
 
 	void                    setShowAuthors(bool bAuthors);
@@ -392,17 +439,21 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 	// data items
 
-	virtual bool			createDataItem(const char * szName, bool bBase64, const UT_ByteBuf * pByteBuf,
-										   const void* pToken, void ** ppHandle);
+	virtual bool			createDataItem(const char * szName, bool bBase64, 
+                                           const UT_ByteBuf * pByteBuf,
+										   const std::string & mime_type, 
+                                           void ** ppHandle);
 	virtual bool            replaceDataItem(const char * szName, const UT_ByteBuf * pByteBuf);
 	virtual bool			getDataItemDataByName(const char * szName,
-												  const UT_ByteBuf ** ppByteBuf, const void** ppToken, void ** ppHandle) const;
+												  const UT_ByteBuf ** ppByteBuf,
+                                                  std::string* pMimeType,
+                                                  void ** ppHandle) const;
 	bool					setDataItemToken(void* pHandle, void* pToken);
 	bool					getDataItemData(void * pHandle,
 											const char ** pszName, const UT_ByteBuf ** ppByteBuf, const void** ppToken) const;
 	bool					getDataItemFileExtension(const char *szDataID, std::string &sExt, bool bDot = true) const;
 	bool					enumDataItems(UT_uint32 k,
-										  void ** ppHandle, const char ** pszName, const UT_ByteBuf ** ppByteBuf, const void** ppToken) const;
+										  void ** ppHandle, const char ** pszName, const UT_ByteBuf ** ppByteBuf, std::string * pMimeType) const;
 
     PL_StruxDocHandle       findHdrFtrStrux(const gchar * pszHdtFtr,
 											const gchar * pszHdrFtrID);
@@ -412,6 +463,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 	bool                    changeStruxAttsNoUpdate(PL_StruxDocHandle sdh, const char * attr, const char * attvalue);
 	bool                    deleteStruxNoUpdate(PL_StruxDocHandle sdh);
+	bool                    deleteFragNoUpdate(pf_Frag * pf);
 	bool                    insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes );
 	bool                    isStruxBeforeThis(PL_StruxDocHandle sdh,  PTStruxType pts);
 
@@ -455,7 +507,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
                                      fd_Field * &pField);
 	po_Bookmark * 			getBookmark(PL_StruxDocHandle sdh, UT_uint32 offset);
 	pf_Frag *               findBookmark(const char * pName, bool bEnd = false, pf_Frag * pfStart = NULL);
-	bool                    hasMathorSVG(void);
+	bool                    hasMath(void);
 
 	void					setDontChangeInsPoint(void);
 	void					allowChangeInsPoint(void);
@@ -492,6 +544,9 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 												 UT_sint32 col);
 	void                    miniDump(PL_StruxDocHandle sdh, UT_sint32 nstruxes);
 
+	bool                    isInsertHyperLinkValid(PT_DocPosition pos) const;
+
+
 	// List Functions
 	fl_AutoNum *			getListByID(UT_uint32 id) const;
 	fl_AutoNum *			getNthList(UT_uint32 i) const;
@@ -525,8 +580,8 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	fp_PageSize             m_docPageSize; // Move this to private later
 	bool					isBookmarkUnique(const gchar * pName) const;
 	bool					isBookmarkRelativeLink(const gchar * pName) const;
-	UT_uint32				getBookmarkCount()const {return m_vBookmarkNames.getItemCount();}
-	const gchar *		getNthBookmark(UT_uint32 n)const{return reinterpret_cast<const gchar *>(m_vBookmarkNames.getNthItem(n));}
+	UT_sint32				getBookmarkCount()const {return m_vBookmarkNames.getItemCount();}
+	const gchar *		getNthBookmark(UT_sint32 n)const{return reinterpret_cast<const gchar *>(m_vBookmarkNames.getNthItem(n));}
 	void					addBookmark(const gchar * pName);
 	void					removeBookmark(const gchar * pName);
 
@@ -724,7 +779,7 @@ protected:
 	bool     _pruneSectionAPI(pf_Frag_Strux * pfs,const char * szHType, UT_GenericVector<pf_Frag_Strux *> *vecHdrFtrs);
 	bool     _matchSection(pf_Frag_Strux * pfs, UT_GenericVector<pf_Frag_Strux *> *vecSections);
 	bool     _removeHdrFtr(pf_Frag_Strux * pfs);
-
+	bool     _checkAndFixTable(pf_Frag_Strux * pfs);
 public:
 	// these functions allow us to retrieve visual direction at document
 	// position pos from an associated layout. They are intended to be
@@ -786,8 +841,8 @@ private:
 	bool                    m_bExportAuthorAtts;
 	UT_sint32               m_iMyAuthorInt;
 	UT_sint32               m_iLastAuthorInt;
-	UT_GenericVector<_ImagePage *> m_pPendingImagePage;
-	UT_GenericVector<_TextboxPage *> m_pPendingTextboxPage;
+	UT_GenericVector<ImagePage *> m_pPendingImagePage;
+	UT_GenericVector<TextboxPage *> m_pPendingTextboxPage;
 };
 
 #endif /* PD_DOCUMENT_H */
