@@ -165,7 +165,7 @@ bool	PP_AttrProp::setAttributes(const gchar ** attributes)
  *
  * \param attributes A UT_Vector of strings, read in (attribute, value) form.
  */
-bool PP_AttrProp::setAttributes(const UT_GenericVector<gchar*> * pVector)
+bool PP_AttrProp::setAttributes(const UT_GenericVector<const gchar*> * pVector)
 {
 	UT_uint32 kLimit = pVector->getItemCount();
 	for (UT_uint32 k=0; k+1<kLimit; k+=2)
@@ -327,8 +327,10 @@ bool	PP_AttrProp::setAttribute(const gchar * szName, const gchar * szValue)
 		char * szDupValue = szValue ? g_strdup(szValue) : NULL;
 
 		// get rid of any illegal chars we might have been given
-		UT_validXML(copy);
-		UT_validXML(szDupValue);
+		if(!UT_isValidXML(copy))
+			UT_validXML(copy);
+		if(!UT_isValidXML(szDupValue))
+			UT_validXML(szDupValue);
 
 		const char * pEntry = m_pAttributes->pick(copy);
 
@@ -398,7 +400,8 @@ bool	PP_AttrProp::setProperty(const gchar * szName, const gchar * szValue)
 	UT_return_val_if_fail( szName && (szValue2 || !szValue), false);
 
 	// get rid of any illegal chars we might have been given in the value
-	UT_validXML(szValue2);
+	if(!UT_isValidXML(szValue2))
+		UT_validXML(szValue2);
 	
 	const PropertyPair * pEntry = m_pProperties->pick(szName);
 	if (pEntry)
@@ -793,7 +796,9 @@ bool PP_AttrProp::isExactMatch(const PP_AttrProp * pMatch) const
 #endif
 
 	UT_return_val_if_fail (pMatch, false);
-	UT_return_val_if_fail (m_bIsReadOnly && pMatch->m_bIsReadOnly, false);
+	//
+	// Why is this here? Nothing is being changed?
+	//	UT_return_val_if_fail (m_bIsReadOnly && pMatch->m_bIsReadOnly, false);
 	if (m_checkSum != pMatch->m_checkSum)
 		return false;
 
@@ -1301,7 +1306,9 @@ void PP_AttrProp::_computeCheckSum(void)
 */
 UT_uint32 PP_AttrProp::getCheckSum(void) const
 {
-	UT_ASSERT_HARMLESS(m_bIsReadOnly);
+  //
+  // Why is this assert present? This is harmless.
+  //	UT_ASSERT_HARMLESS(m_bIsReadOnly);
 	return m_checkSum;
 }
 
@@ -1334,7 +1341,7 @@ void PP_AttrProp::operator = (const PP_AttrProp &Other)
 
 }
 
-UT_uint32 PP_AttrProp::getIndex(void)
+UT_uint32 PP_AttrProp::getIndex(void) const
 {
 	return m_index;
 }
@@ -1509,7 +1516,7 @@ bool PP_AttrProp::explodeStyle(const PD_Document * pDoc, bool bOverwrite)
 			UT_Vector vAttrs;
 			UT_Vector vProps;
 
-			UT_uint32 i;
+			UT_sint32 i;
 
 			pStyle->getAllAttributes(&vAttrs, 100);
 			pStyle->getAllProperties(&vProps, 100);
@@ -1591,5 +1598,7 @@ void PP_AttrProp::miniDump(const PD_Document * pDoc) const
 	}
 	
 	UT_DEBUGMSG(("----------------------------------------------------------------------------\n"));
+#else
+	UT_UNUSED(pDoc);
 #endif
 }
