@@ -189,6 +189,7 @@ static PP_Property _props[] =
 	{ "text-folded-id",        "0",               false, NULL, PP_LEVEL_BLOCK},
 	{ "text-indent",           "0in",             false, NULL, PP_LEVEL_BLOCK},
 	{ "text-position",         "normal",          true,  NULL, PP_LEVEL_CHAR},
+	{ "text-transform",         "none",          true,  NULL, PP_LEVEL_CHAR},
 	{ "toc-dest-style1",      "Contents 1"   ,   false, NULL, PP_LEVEL_BLOCK},
 	{ "toc-dest-style2",      "Contents 2",      false, NULL, PP_LEVEL_BLOCK},
 	{ "toc-dest-style3",      "Contents 3",      false, NULL, PP_LEVEL_BLOCK},
@@ -285,15 +286,17 @@ void PP_resetInitialBiDiValues(const gchar * pszValue)
 		  //this last one is not necessary since dom-dir and column-order
 		  //share the same physical string
 		{
-			strncpy(_props[i].m_pszInitial, pszValue, 3);
+			_props[i].m_pszInitial = pszValue;
 		}
 		else if ((0 == strcmp(_props[i].m_pszName, "text-align")))
 		{
 			UT_DEBUGMSG(("reseting text-align (%s)\n", pszValue));
-			if(pszValue[0] == (gchar)'r')
-				strncpy(_props[i].m_pszInitial,"right", 5);
-			else
-				strncpy(_props[i].m_pszInitial, "left", 4);
+			if(pszValue[0] == (gchar)'r') {
+				_props[i].m_pszInitial = "right";
+			}
+			else {
+				_props[i].m_pszInitial = "left";
+			}
 			break; //since the list is alphabetical, this is always the last one
 		}
 	}
@@ -306,7 +309,7 @@ void PP_setDefaultFontFamily(const char* pszFamily)
 	prop->m_pszInitial = const_cast<gchar*>(reinterpret_cast<const gchar*>(family.c_str()));
 }
 
-static PD_Style * _getStyle(const PP_AttrProp * pAttrProp, PD_Document * pDoc)
+static PD_Style * _getStyle(const PP_AttrProp * pAttrProp, const PD_Document * pDoc)
 {
 	PD_Style * pStyle = NULL;
 
@@ -339,7 +342,7 @@ static PD_Style * _getStyle(const PP_AttrProp * pAttrProp, PD_Document * pDoc)
 
 static const gchar * s_evalProperty (const PP_Property * pProp,
 										const PP_AttrProp * pAttrProp,
-										PD_Document * pDoc,
+										const PD_Document * pDoc,
 										bool bExpandStyles)
 {
 	const gchar * szValue = NULL;
@@ -369,7 +372,7 @@ const gchar * PP_evalProperty (const gchar *  pszName,
 								  const PP_AttrProp * pSpanAttrProp,
 								  const PP_AttrProp * pBlockAttrProp,
 								  const PP_AttrProp * pSectionAttrProp,
-								  PD_Document * pDoc,
+								  const PD_Document * pDoc,
 								  bool bExpandStyles)
 {
 	// find the value for the given property
@@ -560,7 +563,7 @@ const PP_PropertyType * PP_evalPropertyType(const gchar *  pszName,
 								 const PP_AttrProp * pBlockAttrProp,
 								 const PP_AttrProp * pSectionAttrProp,
 								 tProperty_type Type,
-								 PD_Document * pDoc,
+								 const PD_Document * pDoc,
 								 bool bExpandStyles)
 {
 	// find the value for the given property
