@@ -158,8 +158,11 @@ public:
 		abi_table_margin_left,
 		abi_table_margin_right,
 		abi_table_margin_top,
+		abi_table_rel_column_props,
+		abi_table_rel_width,
 		abi_table_row_props,
 		abi_table_row_spacing,
+		abi_table_width,
 		abi_tabstops,
 		abi_text_align,
 		abi_text_decoration,
