@@ -45,63 +45,63 @@ bool pt_PieceTable::_unlinkStrux(pf_Frag_Strux * pfs,
 #if 1
 	if(pfs->getStruxType() == PTX_SectionTable)
 	{
-		UT_DEBUGMSG(("_unlink Strux Table %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux Table %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionCell)
 	{
-		UT_DEBUGMSG(("_unlink Strux Cell %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux Cell %p \n",pfs));
 	}	
 	else if(pfs->getStruxType() == PTX_EndTable)
 	{
-		UT_DEBUGMSG(("_unlink Strux End Table %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux End Table %p \n",pfs));
 	}	
 	else if(pfs->getStruxType() == PTX_EndCell)
 	{
-		UT_DEBUGMSG(("_unlink Strux EndCell %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux EndCell %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionFrame)
 	{
-		UT_DEBUGMSG(("_unlink Strux SectionFrame %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux SectionFrame %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_EndFrame)
 	{
-		UT_DEBUGMSG(("_unlink Strux EndFrame %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux EndFrame %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_Block)
 	{
-		UT_DEBUGMSG(("_unlink Strux Block %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux Block %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_Section)
 	{
-		UT_DEBUGMSG(("_unlink Strux Section %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux Section %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionHdrFtr)
 	{
-		UT_DEBUGMSG(("_unlink HdrFtr Strux Section %x \n",pfs));
+		UT_DEBUGMSG(("_unlink HdrFtr Strux Section %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionFootnote)
 	{
-		UT_DEBUGMSG(("_unlink Strux SectionFootnote %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux SectionFootnote %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_EndFootnote)
 	{
-		UT_DEBUGMSG(("_unlink Strux EndFootnote %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux EndFootnote %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionEndnote)
 	{
-		UT_DEBUGMSG(("_unlink Strux SectionEndnote %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux SectionEndnote %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_EndEndnote)
 	{
-		UT_DEBUGMSG(("_unlink Strux EndEndnote %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux EndEndnote %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_SectionTOC)
 	{
-		UT_DEBUGMSG(("_unlink Strux SectionTOC %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux SectionTOC %p \n",pfs));
 	}
 	else if(pfs->getStruxType() == PTX_EndTOC)
 	{
-		UT_DEBUGMSG(("_unlink Strux EndTOC %x \n",pfs));
+		UT_DEBUGMSG(("_unlink Strux EndTOC %p \n",pfs));
 	}
 //	m_pDocument->miniDump((PL_StruxDocHandle) pfs, 2);
 #endif
@@ -114,11 +114,13 @@ bool pt_PieceTable::_unlinkStrux(pf_Frag_Strux * pfs,
 	case PTX_SectionFrame:
 	case PTX_SectionCell:
 	case PTX_SectionFootnote:
+	case PTX_SectionAnnotation:
 	case PTX_SectionTOC:
 	case PTX_EndCell:
 	case PTX_EndTable:
 	case PTX_EndFootnote:
 	case PTX_EndEndnote:
+	case PTX_EndAnnotation:
 	case PTX_EndFrame:
 	case PTX_EndTOC:
 		return _unlinkStrux_Section(pfs,ppfEnd,pfragOffsetEnd);
@@ -279,6 +281,8 @@ bool pt_PieceTable::_unlinkStrux_Section(pf_Frag_Strux * pfs,
 			  || pfs->getStruxType()==PTX_EndFrame 
 			  || pfs->getStruxType()==PTX_SectionFootnote 
 			  || pfs->getStruxType()==PTX_EndFootnote 
+			  || pfs->getStruxType()==PTX_SectionAnnotation 
+			  || pfs->getStruxType()==PTX_EndAnnotation 
 			  || pfs->getStruxType()==PTX_SectionEndnote 
 			  || pfs->getStruxType()==PTX_EndEndnote
 			  || pfs->getStruxType()==PTX_SectionTOC 
@@ -413,6 +417,24 @@ bool pt_PieceTable::_unlinkStrux_Section(pf_Frag_Strux * pfs,
 		return true;
 
 
+
+	case PTX_SectionAnnotation:
+        //
+        // deleting Annotations is a multi-step process that can't make 
+        // assumptions
+        // on a single step
+		_unlinkFrag(pfs,ppfEnd,pfragOffsetEnd);
+		return true;
+
+	case PTX_EndAnnotation:
+        //
+        // deleting Annotations is a multi-step process that can't make 
+        // assumptions
+        // on a single step
+		_unlinkFrag(pfs,ppfEnd,pfragOffsetEnd);
+		return true;
+
+
 	case PTX_Section:
 	  //
 	  // We can delete Tables provided there is a block to take it's place later
@@ -558,7 +580,7 @@ bool pt_PieceTable::_deleteHdrFtrsFromSectionStruxIfPresent(pf_Frag_Strux_Sectio
 		FooterFirstV = szHeaderV;
 		vecHdrFtr.addItem((void *) FooterFirstV.c_str());
 	}
-	UT_sint32 countHdrFtr = (UT_sint32) vecHdrFtr.getItemCount();
+	UT_sint32 countHdrFtr = vecHdrFtr.getItemCount();
 	UT_DEBUGMSG(("SEVIOR: Deleting HdrFtrs from Document, num Header/Footers %d\n",countHdrFtr));
 	if(0 == countHdrFtr)
 	{
@@ -660,7 +682,7 @@ void pt_PieceTable::_deleteHdrFtrStruxWithNotify( pf_Frag_Strux * pfFragStruxHdr
 		}
 		else
 		{
-			UT_DEBUGMSG(("Adding strux %x of type %d at Pos %d to strux vector for delete \n",pfs,pfs->getStruxType(),pfs->getPos()));
+			UT_DEBUGMSG(("Adding strux %p of type %d at Pos %d to strux vector for delete \n",pfs,pfs->getStruxType(),pfs->getPos()));
 			posLastStrux = pfs->getPos();
 			vecFragStrux.addItem((void *) pfFrag);
 			pfFrag = pfFrag->getNext();
