@@ -31,7 +31,6 @@
 #include "ut_hash.h"
 #include "xap_Strings.h"
 #include "xap_App.h"
-#include "xap_App.h"
 #include "xap_EncodingManager.h"
 
 ///////////////////////////////////////////////////////////////////
@@ -51,7 +50,7 @@
 
 typedef struct
 {
-	char*	pStyle;
+	const char*	pStyle;
 	int		nID;	
 	
 } ST_LOCALISED_STYLES;
@@ -137,7 +136,7 @@ bool pt_PieceTable::_loadBuiltinStyles(void)
 	*/
 	UT_LocaleTransactor t(LC_NUMERIC, "C");
 
-	char* list_fmt = " list-style:%s; start-value:%s; margin-left:%fin; text-indent:-%fin; "
+	const char* list_fmt = " list-style:%s; start-value:%s; margin-left:%fin; text-indent:-%fin; "
 		"field-color:%s;list-delim:%s; field-font:%s; list-decimal:%s";
 	UT_String list_fmt_tmp;
 	UT_String stTmp;
@@ -359,6 +358,7 @@ bool pt_PieceTable::appendStyle(const gchar ** attributes)
 
 //
 // TODO: Learn how to use Dom's AbiObject instead of this hack.
+// Rob asks, as AbiObject is no more, is this still a hack?
 //
 
 		if (pStyle)
@@ -407,7 +407,7 @@ bool pt_PieceTable::getStyle(const char * szName, PD_Style ** ppStyle) const
 	return true;
 }
 
-size_t pt_PieceTable::getStyleCount (void)
+size_t pt_PieceTable::getStyleCount (void) const
 {
   return (size_t) m_hashStyles.size();
 }
