@@ -1,6 +1,6 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
- * Copyright (C) 2003, 2005 Hubert Figuiere
+ * Copyright (C) 2003, 2005, 2009 Hubert Figuiere
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 #include "xap_CocoaApp.h"
 #include "xap_CocoaFrame.h"
 
+#include "gr_CocoaCairoGraphics.h"
 #include "ap_Strings.h"
 #include "ap_Dialog_Id.h"
 #include "fl_DocLayout.h"
@@ -73,6 +74,7 @@
 - (IBAction)newAction:(id)sender;
 
 - (void)setStyleDescription:(NSString*)desc;
+- (BOOL)control:(NSControl *)control textShouldBeginEditing:(NSText *)editor;
 @end
 
 @interface AP_CocoaDialog_StylesModifyController : NSWindowController <XAP_CocoaDialogProtocol>
@@ -169,8 +171,8 @@ void AP_CocoaDialog_Styles::runModal(XAP_Frame * pFrame)
 	DELETEP (m_pParaPreviewWidget);
 	XAP_CocoaNSView * preview = m_dlg->_paraPreview;
 	{
-		GR_CocoaAllocInfo ai(preview);
-		m_pParaPreviewWidget = (GR_CocoaGraphics*)XAP_App::getApp()->newGraphics(ai);
+		GR_CocoaCairoAllocInfo ai(preview);
+		m_pParaPreviewWidget = (GR_CocoaCairoGraphics*)XAP_App::getApp()->newGraphics(ai);
 	}
 	
         // let the widget materialize
@@ -182,8 +184,8 @@ void AP_CocoaDialog_Styles::runModal(XAP_Frame * pFrame)
 	DELETEP (m_pCharPreviewWidget);
 	preview = m_dlg->_charPreview;
 	{
-		GR_CocoaAllocInfo ai(preview);
-		m_pCharPreviewWidget = (GR_CocoaGraphics*)XAP_App::getApp()->newGraphics(ai);
+		GR_CocoaCairoAllocInfo ai(preview);
+		m_pCharPreviewWidget = (GR_CocoaCairoGraphics*)XAP_App::getApp()->newGraphics(ai);
 	}
 
 	// let the widget materialize
@@ -494,8 +496,8 @@ void  AP_CocoaDialog_Styles::modifyRunModal(void)
 		// make a new Cocoa GC
 		DELETEP (m_pAbiPreviewWidget);
 		XAP_CocoaNSView * preview = m_modifyDlg->_preview;
-		GR_CocoaAllocInfo ai(preview);
-		m_pAbiPreviewWidget = (GR_CocoaGraphics*)XAP_App::getApp()->newGraphics(ai);
+		GR_CocoaCairoAllocInfo ai(preview);
+		m_pAbiPreviewWidget = (GR_CocoaCairoGraphics*)XAP_App::getApp()->newGraphics(ai);
 
 		
 			// let the widget materialize
@@ -909,6 +911,14 @@ void   AP_CocoaDialog_Styles::event_ModifyTabs()
 	[_descriptionData setStringValue:desc];
 }
 
+- (BOOL)control:(NSControl *)control textShouldBeginEditing:(NSText *)editor;
+{
+	UT_UNUSED(editor);
+	if(control == _availStylesList) {
+		return NO;
+	}
+	return YES;
+}
 @end
 
 
