@@ -260,21 +260,14 @@ void AP_UnixDialog_Options::addPage ( const XAP_NotebookDialog::Page *page )
 void AP_UnixDialog_Options::_setupUnitMenu ( GtkWidget *optionmenu, const XAP_StringSet *pSS )
 {
 	GtkComboBox *combo = GTK_COMBO_BOX(optionmenu);
-    std::string s;
-
+	UnitMenuContent content;
+	_getUnitMenuContent(pSS, content);
 	XAP_makeGtkComboBoxText(combo, G_TYPE_INT);
-    // inches
-    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_inch, s );
-	XAP_appendComboBoxTextAndInt(combo, s.c_str(), DIM_IN);
-    // cm
-    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_cm, s );
-	XAP_appendComboBoxTextAndInt(combo, s.c_str(), DIM_CM);
-    // points
-    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_points, s );
-	XAP_appendComboBoxTextAndInt(combo, s.c_str(), DIM_PT);
-    // picas
-    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_pica, s );
-	XAP_appendComboBoxTextAndInt(combo, s.c_str(), DIM_PI);
+	
+	for(UnitMenuContent::const_iterator iter = content.begin();
+		iter != content.end(); ++iter) {
+		XAP_appendComboBoxTextAndInt(combo, iter->first.c_str(), iter->second);
+	}
 	gtk_combo_box_set_active(combo, 0);
 }
 
@@ -327,6 +320,10 @@ void AP_UnixDialog_Options::_constructWindowContents ( GtkBuilder * builder )
     tmp = WID ( "lblScreenColor" );
     localizeLabelUnderline ( tmp, pSS, AP_STRING_ID_DLG_Options_Label_ChooseForTransparent );
 
+    m_checkbuttonEnableOverwrite = WID ( "btnOverwrite" );
+    localizeButtonUnderline ( m_checkbuttonEnableOverwrite, pSS,
+                              AP_STRING_ID_DLG_Options_Label_EnableOverwrite );    
+
 #if !defined(EMBEDDED_TARGET) || EMBEDDED_TARGET != EMBEDDED_TARGET_HILDON
     // Application Startup
     tmp = WID ( "lblApplicationStartup" );
@@ -641,6 +638,8 @@ GtkWidget *AP_UnixDialog_Options::_lookupWidget ( tControl id )
 
         case id_PUSH_CHOOSE_COLOR_FOR_TRANSPARENT:
             return  m_pushbuttonNewTransparentColor;
+        case id_CHECK_ENABLE_OVERWRITE:
+            return m_checkbuttonEnableOverwrite;
 
             // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
             // general
@@ -743,6 +742,7 @@ DEFINE_GET_SET_BOOL ( CustomSmartQuotes )
 DEFINE_GET_SET_BOOL ( OtherDirectionRtl )
 
 DEFINE_GET_SET_BOOL ( AutoSaveFile )
+DEFINE_GET_SET_BOOL ( EnableOverwrite )
 
 // dummy implementations. XP pref backend isn't very smart.
 #define DEFINE_GET_SET_BOOL_DUMMY(Bool)     \
