@@ -87,18 +87,6 @@ _ev_convert (char * bufResult,
 	return bufResult;
 }
 
-static int
-fp_2_pos (UT_Dimension u)
-{
-   switch (u)
-    {
-    case DIM_CM : return 1;
-    case DIM_MM : return 2;
-    case DIM_IN :
-    default :
-      return 0;
-    } 
-}
 
 /*********************************************************************************/
 
@@ -218,15 +206,15 @@ void AP_UnixDialog_PageSetup::_setHeight(const char * buf)
 
 void AP_UnixDialog_PageSetup::event_LandscapeChanged(void)
 {
-	UT_UTF8String sHeight = gtk_entry_get_text(GTK_ENTRY(m_entryPageHeight));
-	UT_UTF8String sWidth = gtk_entry_get_text(GTK_ENTRY(m_entryPageWidth));
+	std::string sHeight = gtk_entry_get_text(GTK_ENTRY(m_entryPageHeight));
+	std::string sWidth = gtk_entry_get_text(GTK_ENTRY(m_entryPageWidth));
 
-	_setWidth(sHeight.utf8_str());
-	_setHeight(sWidth.utf8_str());
+	_setWidth(sHeight.c_str());
+	_setHeight(sWidth.c_str());
 	g_signal_handler_block(G_OBJECT(m_entryPageWidth), m_iEntryPageWidthID);
 	g_signal_handler_block(G_OBJECT(m_entryPageHeight), m_iEntryPageHeightID);
-	gtk_entry_set_text( GTK_ENTRY(m_entryPageWidth),sHeight.utf8_str() );
-	gtk_entry_set_text( GTK_ENTRY(m_entryPageHeight),sWidth.utf8_str() );
+	gtk_entry_set_text( GTK_ENTRY(m_entryPageWidth),sHeight.c_str() );
+	gtk_entry_set_text( GTK_ENTRY(m_entryPageHeight),sWidth.c_str() );
 	g_signal_handler_unblock(G_OBJECT(m_entryPageWidth), m_iEntryPageWidthID);
 	g_signal_handler_unblock(G_OBJECT(m_entryPageHeight), m_iEntryPageHeightID);
 
@@ -309,7 +297,6 @@ void AP_UnixDialog_PageSetup::event_OK (void)
 	}
 	
 	setMarginUnits (last_margin_unit);
-	setPageUnits (fp.getDims());
 	setPageSize (fp);
 	setPageOrientation (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (m_radioPagePortrait)) ? PORTRAIT : LANDSCAPE);
 	setPageScale (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (m_spinPageScale)));
@@ -354,19 +341,29 @@ void AP_UnixDialog_PageSetup::event_PageUnitsChanged (void)
 	width  = static_cast<double>(ps.Width (pu));
 	height = static_cast<double>(ps.Height (pu));
 
-	m_PageSize.Set(width, height, pu);
-	setPageUnits(pu);
-
+	if(m_PageSize.isPortrait())
+	{
+	    m_PageSize.Set(width, height, pu);
+	}
+	else
+	{
+	    m_PageSize.Set(height,width, pu);
+	}
 	// set values
 	gchar * val;
-
-	val = g_strdup_printf (FMT_STRING, static_cast<float>(width));
-	gtk_entry_set_text (GTK_ENTRY (m_entryPageWidth), val);
-	g_free (val);
-
-	val = g_strdup_printf (FMT_STRING, static_cast<float>(height));
-	gtk_entry_set_text (GTK_ENTRY (m_entryPageHeight), val);
-	g_free (val);
+	{
+	  XAP_GtkSignalBlocker b(G_OBJECT(m_entryPageWidth), m_iEntryPageWidthID);
+	  val = g_strdup_printf (FMT_STRING, static_cast<float>(width));
+	  gtk_entry_set_text (GTK_ENTRY (m_entryPageWidth), val);
+	  g_free (val);
+	}
+	{
+	  XAP_GtkSignalBlocker C(G_OBJECT(m_entryPageHeight), m_iEntryPageHeightID);
+	  val = g_strdup_printf (FMT_STRING, static_cast<float>(height));
+	  gtk_entry_set_text (GTK_ENTRY (m_entryPageHeight), val);
+	  g_free (val);
+	}
+	setPageUnits(pu);
 }
 
 void AP_UnixDialog_PageSetup::event_PageSizeChanged (fp_PageSize::Predefined pd)
@@ -376,13 +373,12 @@ void AP_UnixDialog_PageSetup::event_PageSizeChanged (fp_PageSize::Predefined pd)
 	{
 		ps.setLandscape();
 	}
-	// hmm, we should g_free the old pagesize.
 	m_PageSize = ps;
-	setPageUnits(ps.getDims());
 
 	// change the units in the dialog, too.
 	UT_Dimension new_units = ps.getDims();
-	gtk_combo_box_set_active (GTK_COMBO_BOX (m_optionPageUnits), fp_2_pos (new_units));
+	setPageUnits(new_units);
+	XAP_comboBoxSetActiveFromIntCol(GTK_COMBO_BOX (m_optionPageUnits), 1, new_units);
 
 	float w, h;
 
@@ -398,7 +394,8 @@ void AP_UnixDialog_PageSetup::event_PageSizeChanged (fp_PageSize::Predefined pd)
   {
 	  // set entry values for a non-custom pagesize
 	  gchar * val;
-
+	  XAP_GtkSignalBlocker b(G_OBJECT(m_entryPageWidth), m_iEntryPageWidthID);
+	  XAP_GtkSignalBlocker c(G_OBJECT(m_entryPageHeight), m_iEntryPageHeightID);
 	  val = g_strdup_printf (FMT_STRING, w);
  	  _setWidth(val);
 	  gtk_entry_set_text (GTK_ENTRY (m_entryPageWidth), val);
@@ -652,7 +649,7 @@ GtkWidget * AP_UnixDialog_PageSetup::_constructWindow (void)
 	XAP_appendComboBoxTextAndInt(combo, _(XAP, DLG_Unit_inch), DIM_IN);
 	XAP_appendComboBoxTextAndInt(combo, _(XAP, DLG_Unit_cm), DIM_CM);
 	XAP_appendComboBoxTextAndInt(combo, _(XAP, DLG_Unit_mm), DIM_MM);
-	gtk_combo_box_set_active(combo, fp_2_pos (getPageUnits()));
+    XAP_comboBoxSetActiveFromIntCol(combo, 1, getPageUnits ());
 
 	/* setup margin units menu */
 	combo = GTK_COMBO_BOX(m_optionMarginUnits);
@@ -661,7 +658,7 @@ GtkWidget * AP_UnixDialog_PageSetup::_constructWindow (void)
 	XAP_appendComboBoxTextAndInt(combo, _(XAP, DLG_Unit_cm), DIM_CM);
 	XAP_appendComboBoxTextAndInt(combo, _(XAP, DLG_Unit_mm), DIM_MM);
 	last_margin_unit = getMarginUnits ();
-	gtk_combo_box_set_active(combo, fp_2_pos(last_margin_unit));
+    XAP_comboBoxSetActiveFromIntCol(combo, 1, last_margin_unit);
 
 	/* add margin XPM image to the margin window */
 	customPreview = create_pixmap (m_MarginHbox, margin_xpm);
