@@ -86,8 +86,11 @@ void AP_Dialog_Options::_storeWindowData(void)
 	XAP_Prefs *pPrefs = m_pApp->getPrefs();
 	UT_return_if_fail (pPrefs);
 
-	AP_FrameData *pFrameData = (AP_FrameData *)m_pFrame->getFrameData();
-	UT_return_if_fail (pFrameData);
+	AP_FrameData *pFrameData = NULL;
+	if(m_pFrame) {
+		pFrameData = (AP_FrameData *)m_pFrame->getFrameData();
+		UT_return_if_fail (pFrameData);
+	}
 
 	XAP_PrefsScheme *pPrefsScheme = pPrefs->getCurrentScheme();
 	UT_return_if_fail (pPrefsScheme);
@@ -137,6 +140,7 @@ void AP_Dialog_Options::_storeWindowData(void)
 #if defined(TOOLKIT_GTK)
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_EnableSmoothScrolling, _gatherEnableSmoothScrolling() );
 #endif
+    Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_InsertModeToggle, _gatherEnableOverwrite() );
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_AutoLoadPlugins, _gatherAutoLoadPlugins() );
 	Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_DefaultDirectionRtl, _gatherOtherDirectionRtl() );
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_ChangeLanguageWithKeyboard, _gatherLanguageWithKeyboard() );
@@ -169,7 +173,7 @@ void AP_Dialog_Options::_storeWindowData(void)
 	// or hidden, then update the current window:
 	// (If we didn't change anything, leave it alone)
 #if !defined(TOOLKIT_GTK) && !defined(TOOLKIT_COCOA) && !defined (TOOLKIT_WIN) 
-	if ( _gatherViewShowRuler() != pFrameData->m_bShowRuler )
+	if (pFrameData && _gatherViewShowRuler() != pFrameData->m_bShowRuler )
 	{
 		pFrameData->m_bShowRuler = _gatherViewShowRuler() ;
 		if (!pFrameData->m_bIsFullScreen)
@@ -179,7 +183,7 @@ void AP_Dialog_Options::_storeWindowData(void)
 	}
 
 	// Same for status bar
-	if (_gatherViewShowStatusBar() != pFrameData->m_bShowStatusBar)
+	if (pFrameData && _gatherViewShowStatusBar() != pFrameData->m_bShowStatusBar)
 	{
 		pFrameData->m_bShowStatusBar = _gatherViewShowStatusBar();
 		if (!pFrameData->m_bIsFullScreen)
@@ -189,19 +193,21 @@ void AP_Dialog_Options::_storeWindowData(void)
 	}
 
 
-	for (i = 0; i < m_pApp->getToolbarFactory()->countToolbars(); i++) {
-		if (_gatherViewShowToolbar(i) != pFrameData->m_bShowBar[i])
-		{
-			pFrameData->m_bShowBar[i] = _gatherViewShowToolbar(i);
-			if (!pFrameData->m_bIsFullScreen)
+	if(pFrameData) {
+		for (i = 0; i < m_pApp->getToolbarFactory()->countToolbars(); i++) {
+			if (_gatherViewShowToolbar(i) != pFrameData->m_bShowBar[i])
 			{
-				m_pFrame->toggleBar(i, pFrameData->m_bShowBar[i]);
+				pFrameData->m_bShowBar[i] = _gatherViewShowToolbar(i);
+				if (!pFrameData->m_bIsFullScreen)
+				{
+					m_pFrame->toggleBar(i, pFrameData->m_bShowBar[i]);
+				}
 			}
 		}
 	}
 #endif
 	
-	if ( _gatherViewUnprintable() != pFrameData->m_bShowPara )
+	if (pFrameData &&  _gatherViewUnprintable() != pFrameData->m_bShowPara )
 	{
 		pFrameData->m_bShowPara = _gatherViewUnprintable() ;
 		AV_View * pAVView = m_pFrame->getCurrentView();
@@ -258,8 +264,11 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 	XAP_Prefs *pPrefs = m_pApp->getPrefs();
 	UT_return_if_fail (pPrefs);
 
-	AP_FrameData *pFrameData = (AP_FrameData *)m_pFrame->getFrameData();
-	UT_return_if_fail (pFrameData);
+	AP_FrameData *pFrameData = NULL;
+	if(m_pFrame) {
+		pFrameData = (AP_FrameData *)m_pFrame->getFrameData();
+		UT_return_if_fail (pFrameData);
+	}
 
 	XAP_PrefsScheme *pPrefsScheme = pPrefs->getCurrentScheme();
 	UT_return_if_fail (pPrefsScheme);
@@ -337,7 +346,7 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 			{
 				bool tmpbool = _gatherViewShowRuler();
 				Save_Pref_Bool (pPrefsScheme, AP_PREF_KEY_RulerVisible, tmpbool);
-				if (tmpbool != pFrameData->m_bShowRuler)
+				if (pFrameData && (tmpbool != pFrameData->m_bShowRuler))
 				{
 					pFrameData->m_bShowRuler = _gatherViewShowRuler() ;
 					m_pFrame->toggleRuler(pFrameData->m_bShowRuler);
@@ -362,7 +371,7 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 			{
 				bool tmpbool = _gatherViewShowStatusBar();
 				Save_Pref_Bool (pPrefsScheme, AP_PREF_KEY_StatusBarVisible, tmpbool);
-				if (tmpbool != pFrameData->m_bShowStatusBar)
+				if (pFrameData && (tmpbool != pFrameData->m_bShowStatusBar))
 				{
 					pFrameData->m_bShowStatusBar = tmpbool;
 					m_pFrame->toggleStatusBar(pFrameData->m_bShowStatusBar);
@@ -388,7 +397,10 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 					_gatherEnableSmoothScrolling());
 #endif
 			break;
-
+        case id_CHECK_ENABLE_OVERWRITE:
+			Save_Pref_Bool (pPrefsScheme, AP_PREF_KEY_InsertModeToggle,
+					_gatherEnableOverwrite() );
+            break;
 		case id_CHECK_AUTO_LOAD_PLUGINS:
 			Save_Pref_Bool (pPrefsScheme, XAP_PREF_KEY_AutoLoadPlugins,
 					_gatherAutoLoadPlugins() );
@@ -418,7 +430,6 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 		case id_BUTTON_CANCEL:
 		case id_BUTTON_APPLY:
 		case id_BUTTON_SPELL_AUTOREPLACE:
-		case id_LIST_VIEW_TOOLBARS: // this is needed for the Cocoa front-end to fetch the control
 		case id_CHECK_COLOR_FOR_TRANSPARENT_IS_WHITE:
 		case id_TEXT_AUTO_SAVE_FILE_PERIOD_SPIN:  // needed by Cocoa FE
 
@@ -525,6 +536,10 @@ void AP_Dialog_Options::_populateWindowData(void)
 		_setViewShowStatusBar (b);
 #endif	
 
+
+	if (pPrefs->getPrefsValueBool((gchar*)AP_PREF_KEY_InsertModeToggle,&b))
+		_setEnableOverwrite (b);
+
 	if (pPrefs->getPrefsValueBool((gchar*)AP_PREF_KEY_ParaVisible,&b))
 		_setViewUnprintable (b);
 
@@ -613,6 +628,21 @@ void AP_Dialog_Options::_enableDisableLogic( tControl id )
 	}
 }
 
+
+void AP_Dialog_Options::_getUnitMenuContent(const XAP_StringSet *pSS, UnitMenuContent & content)
+{
+    std::string s;
+    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_inch, s );
+	content.push_back(std::make_pair(s, (int)DIM_IN));
+    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_cm, s );
+	content.push_back(std::make_pair(s, (int)DIM_CM));
+    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_points, s );
+	content.push_back(std::make_pair(s, (int)DIM_PT));
+    pSS->getValueUTF8 ( XAP_STRING_ID_DLG_Unit_pica, s );
+	content.push_back(std::make_pair(s, (int)DIM_PI));
+}
+
+
 // The initialize the controls (i.e., disable controls not coded yet)
 void AP_Dialog_Options::_initEnableControls()
 {
